@@ -1,15 +1,6 @@
 /*
- * Copyright (C) 2023 by Claudio Cambra <claudio.cambra@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 import FileProvider
@@ -33,13 +24,19 @@ extension FileProviderExtension: NSFileProviderThumbnailing {
             completionHandler(NSFileProviderError(.notAuthenticated))
             return Progress()
         }
+        guard let dbManager else {
+            completionHandler(NSFileProviderError(.cannotSynchronize))
+            return Progress()
+        }
 
         return NextcloudFileProviderKit.fetchThumbnails(
             for: itemIdentifiers,
             requestedSize: size,
             account: ncAccount,
             usingRemoteInterface: self.ncKit,
+            andDatabase: dbManager,
             perThumbnailCompletionHandler: perThumbnailCompletionHandler,
+            log: log,
             completionHandler: completionHandler
         )
     }
