@@ -2,7 +2,8 @@
 //  FPUIExtensionCommunicationService.swift
 //  FileProviderExt
 //
-//  Created by Claudio Cambra on 21/2/24.
+//  SPDX-FileCopyrightText: 2024 Nextcloud GmbH and Nextcloud contributors
+//  SPDX-License-Identifier: GPL-2.0-or-later
 //
 
 import FileProvider
@@ -12,12 +13,16 @@ import NextcloudFileProviderKit
 import OSLog
 
 class FPUIExtensionServiceSource: NSObject, NSFileProviderServiceSource, NSXPCListenerDelegate, FPUIExtensionService {
+    let keychain: Keychain
     let listener = NSXPCListener.anonymous()
+    let logger: FileProviderLogger
     let serviceName = fpUiExtensionServiceName
     let fpExtension: FileProviderExtension
 
     init(fpExtension: FileProviderExtension) {
-        Logger.fpUiExtensionService.debug("Instantiating FPUIExtensionService service")
+        keychain = Keychain(log: fpExtension.log)
+        logger = FileProviderLogger(category: "FPUIExtensionServiceSource", log: fpExtension.log)
+        logger.debug("Instantiating FPUIExtensionService service")
         self.fpExtension = fpExtension
         super.init()
     }
@@ -40,11 +45,27 @@ class FPUIExtensionServiceSource: NSObject, NSFileProviderServiceSource, NSXPCLi
 
     //MARK: - FPUIExtensionService protocol methods
 
+    func authenticate() async -> NSError? {
+        logger.info("Authenticating...")
+
+        guard let user = fpExtension.config.user, let userId = fpExtension.config.userId, let serverUrl = fpExtension.config.serverUrl, let password = keychain.getPassword(for: user, on: serverUrl) else {
+            logger.error("Missing account information, cannot authenticate!")
+            return NSError(.missingAccountInformation)
+        }
+
+        return await withCheckedContinuation { continuation in
+            fpExtension.setupDomainAccount(user: user, userId: userId, serverUrl: serverUrl, password: password) { error in
+                continuation.resume(returning: error)
+            }
+        }
+    }
+
     func userAgent() async -> NSString? {
         guard let account = fpExtension.ncAccount?.ncKitAccount else {
             return nil
         }
-        let nkSession = fpExtension.ncKit.getSession(account: account)
+
+        let nkSession = fpExtension.ncKit.nkCommonInstance.nksessions.session(forAccount: account)
         return nkSession?.userAgent as NSString?
     }
 
@@ -54,16 +75,23 @@ class FPUIExtensionServiceSource: NSObject, NSFileProviderServiceSource, NSXPCLi
 
     func itemServerPath(identifier: NSFileProviderItemIdentifier) async -> NSString? {
         let rawIdentifier = identifier.rawValue
-        Logger.shares.info("Fetching shares for item \(rawIdentifier, privacy: .public)")
+        logger.info("Fetching shares for item \(rawIdentifier)")
 
         guard let baseUrl = fpExtension.ncAccount?.davFilesUrl else {
-            Logger.shares.error("Could not fetch shares as ncAccount on parent extension is nil")
+            logger.error("Could not fetch shares as ncAccount on parent extension is nil")
             return nil
         }
 
-        let dbManager = FilesDatabaseManager.shared
+        guard let account = fpExtension.ncAccount?.ncKitAccount else {
+            logger.error("Could not fetch ncKitAccount on parent extension")
+            return nil
+        }
+        guard let dbManager = fpExtension.dbManager else {
+            logger.error("Could not get db manager for \(account)")
+            return nil
+        }
         guard let item = dbManager.itemMetadataFromFileProviderItemIdentifier(identifier) else {
-            Logger.shares.error("No item \(rawIdentifier, privacy: .public) in db, no shares.")
+            logger.error("No item \(rawIdentifier) in db, no shares.")
             return nil
         }
 
