@@ -2,7 +2,8 @@
 //  ShareOptionsView.swift
 //  FileProviderUIExt
 //
-//  Created by Claudio Cambra on 28/2/24.
+//  SPDX-FileCopyrightText: 2024 Nextcloud GmbH and Nextcloud contributors
+//  SPDX-License-Identifier: GPL-2.0-or-later
 //
 
 import AppKit
@@ -13,6 +14,8 @@ import OSLog
 import SuggestionsTextFieldKit
 
 class ShareOptionsView: NSView {
+    var logger: FileProviderLogger?
+
     @IBOutlet private weak var optionsTitleTextField: NSTextField!
     @IBOutlet private weak var shareRecipientTextField: NSTextField!  // Hide if public link share
     @IBOutlet private weak var labelTextField: NSTextField!
@@ -27,31 +30,41 @@ class ShareOptionsView: NSView {
     @IBOutlet private weak var saveButton: NSButton!
     @IBOutlet private weak var deleteButton: NSButton!
     @IBOutlet private weak var shareTypePicker: NSPopUpButton!
+
+    // Share type picker options
     @IBOutlet private weak var publicLinkShareMenuItem: NSMenuItem!
     @IBOutlet private weak var userShareMenuItem: NSMenuItem!
     @IBOutlet private weak var groupShareMenuItem: NSMenuItem!
     @IBOutlet private weak var emailShareMenuItem: NSMenuItem!
     @IBOutlet private weak var federatedCloudShareMenuItem: NSMenuItem!
-    @IBOutlet private weak var circleShare: NSMenuItem!
+    @IBOutlet private weak var teamShare: NSMenuItem!
     @IBOutlet private weak var talkConversationShare: NSMenuItem!
 
     let kit = NextcloudKit.shared
     var account: Account? {
         didSet {
-            Logger.shareOptionsView.info("Setting up account.")
+            logger?.info("Setting up account.")
+
             guard let account else {
-                Logger.shareOptionsView.error("Could not configure suggestions data source.")
+                logger?.error("Could not configure suggestions data source.")
                 return
             }
 
-            suggestionsTextFieldDelegate.suggestionsDataSource = ShareeSuggestionsDataSource(
-                account: account, kit: kit
-            )
-            suggestionsTextFieldDelegate.confirmationHandler = { suggestion in
-                guard let sharee = suggestion?.data as? NKSharee else { return }
-                self.shareRecipientTextField.stringValue = sharee.shareWith
-                Logger.shareOptionsView.debug("Chose sharee \(sharee.shareWith, privacy: .public)")
+            guard let controller else {
+                return
             }
+
+            suggestionsTextFieldDelegate.suggestionsDataSource = ShareeSuggestionsDataSource(account: account, kit: kit, log: controller.log)
+
+            suggestionsTextFieldDelegate.confirmationHandler = { suggestion in
+                guard let sharee = suggestion?.data as? NKSharee else {
+                    return
+                }
+
+                self.shareRecipientTextField.stringValue = sharee.shareWith
+                self.logger?.debug("Chose sharee \(sharee.shareWith)")
+            }
+
             suggestionsTextFieldDelegate.targetTextField = shareRecipientTextField
         }
     }
@@ -59,11 +72,9 @@ class ShareOptionsView: NSView {
     var controller: ShareController? {
         didSet {
             guard controller != nil else { return }
-            optionsTitleTextField.stringValue = "Share options"
-            deleteButton.title = "Delete"
-            deleteButton.image = NSImage(
-                systemSymbolName: "trash", accessibilityDescription: "Delete trash icon"
-            )
+            optionsTitleTextField.stringValue = String(localized: "Share options")
+            deleteButton.title = String(localized: "Delete")
+            deleteButton.image = NSImage(systemSymbolName: "trash", accessibilityDescription: String(localized: "Delete trash icon"))
             deleteButton.bezelColor = NSColor.systemRed
             cancellable?.cancel()
             createMode = false
@@ -73,15 +84,15 @@ class ShareOptionsView: NSView {
     }
     var createMode = false {
         didSet {
-            Logger.shareOptionsView.info("Create mode set: \(self.createMode, privacy: .public)")
+            logger?.info("Create mode set: \(self.createMode)")
             shareTypePicker.isHidden = !createMode
             shareRecipientTextField.isHidden = !createMode
             labelTextField.isHidden = createMode  // Cannot set label on create API call
             guard createMode else { return }
-            optionsTitleTextField.stringValue = "Create new share"
-            deleteButton.title = "Cancel"
+            optionsTitleTextField.stringValue = String(localized: "Create new share")
+            deleteButton.title = String(localized: "Cancel")
             deleteButton.image = NSImage(
-                systemSymbolName: "xmark.bin", accessibilityDescription: "Cancel create icon"
+                systemSymbolName: "xmark.bin", accessibilityDescription: String(localized: "Cancel create icon")
             )
             deleteButton.bezelColor = NSColor.controlColor
             cancellable?.cancel()
@@ -95,8 +106,31 @@ class ShareOptionsView: NSView {
     private var suggestionsWindowController = SuggestionsWindowController()
     private var suggestionsTextFieldDelegate = SuggestionsTextFieldDelegate()
 
+    func applyLocalizedStrings() {
+        publicLinkShareMenuItem.title = String(localized: "Public link share")
+        userShareMenuItem.title = String(localized: "User share")
+        groupShareMenuItem.title = String(localized: "Group share")
+        emailShareMenuItem.title = String(localized: "Email share")
+        federatedCloudShareMenuItem.title = String(localized: "Federated cloud share")
+        teamShare.title = String(localized: "Team share")
+        talkConversationShare.title = String(localized: "Talk conversation share")
+
+        shareRecipientTextField.placeholderString = String(localized: "Share recipient")
+        labelTextField.placeholderString = String(localized: "Share label")
+        uploadEditPermissionCheckbox.title = String(localized: "Allow upload and editing")
+        hideDownloadCheckbox.title = String(localized: "Hide download")
+        passwordProtectCheckbox.title = String(localized: "Password protect")
+        passwordSecureField.placeholderString = String(localized: "Enter a new password")
+        expirationDateCheckbox.title = String(localized: "Expiration date")
+        noteForRecipientCheckbox.title = String(localized: "Note for the recipient")
+        noteTextField.placeholderString = String(localized: "Note for the recipient")
+
+        deleteButton.title = String(localized: "Delete")
+        saveButton.title = String(localized: "Save")
+    }
+
     private func update() {
-        guard let share = controller?.share else {
+        guard let controller else {
             reset()
             setAllFields(enabled: false)
             saveButton.isEnabled = false
@@ -104,6 +138,9 @@ class ShareOptionsView: NSView {
             return
         }
 
+        logger = FileProviderLogger(category: "ShareOptionsView", log: controller.log)
+        let share = controller.share
+
         deleteButton.isEnabled = share.canDelete
         saveButton.isEnabled = share.canEdit
 
@@ -213,8 +250,8 @@ class ShareOptionsView: NSView {
             selectedShareType = .email
         } else if selectedShareTypeItem == federatedCloudShareMenuItem {
             selectedShareType = .federatedCloud
-        } else if selectedShareTypeItem == circleShare {
-            selectedShareType = .circle
+        } else if selectedShareTypeItem == teamShare {
+            selectedShareType = .team
         } else if selectedShareTypeItem == talkConversationShare {
             selectedShareType = .talkConversation
         }
@@ -255,18 +292,13 @@ class ShareOptionsView: NSView {
             let uploadAndEdit = uploadEditPermissionCheckbox.state == .on
 
             guard !createMode else {
-                Logger.shareOptionsView.info("Creating new share!")
+                logger?.info("Creating new share!")
 
                 guard let dataSource,
                       let account,
                       let itemServerRelativePath = dataSource.itemServerRelativePath
                 else {
-                    Logger.shareOptionsView.error("Cannot create new share due to missing data.")
-                    Logger.shareOptionsView.error("dataSource: \(self.dataSource, privacy: .public)")
-                    Logger.shareOptionsView.error("account: \(self.account != nil, privacy: .public)")
-                    Logger.shareOptionsView.error(
-                        "path: \(self.dataSource?.itemServerRelativePath ?? "", privacy: .public)"
-                    )
+                    logger?.error("Cannot create new share due to missing data. dataSource: \(String(describing: self.dataSource)) account: \(self.account != nil) path: \(self.dataSource?.itemServerRelativePath ?? "")")
                     return
                 }
 
@@ -295,7 +327,7 @@ class ShareOptionsView: NSView {
                     hideDownload: hideDownload
                 )
                 if let error = error, error != .success {
-                    dataSource.uiDelegate?.showError("Error creating: \(error.errorDescription)")
+                    dataSource.uiDelegate?.showError(String(localized: "Error creating: \(error.errorDescription)"))
                     setAllFields(enabled: true)
                 } else {
                     dataSource.uiDelegate?.hideOptions(self)
@@ -304,10 +336,10 @@ class ShareOptionsView: NSView {
                 return
             }
 
-            Logger.shareOptionsView.info("Editing existing share!")
+            logger?.info("Editing existing share!")
 
             guard let controller = controller else {
-                Logger.shareOptionsView.error("No valid share controller, cannot edit share.")
+                logger?.error("No valid share controller, cannot edit share.")
                 return
             }
             let share = controller.share
@@ -355,3 +387,4 @@ class ShareOptionsView: NSView {
         }
     }
 }
+
