@@ -1,20 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "utility.h"
@@ -78,6 +65,24 @@ bool Utility::hasLaunchOnStartup(const QString &appName)
     return QFile::exists(desktopFileLocation);
 }
 
+void Utility::migrateFavLink(const QString &folder)
+{
+    Q_UNUSED(folder)
+}
+
+void Utility::setupDesktopIni(const QString &folder, const QString localizedResourceName)
+{
+    Q_UNUSED(folder)
+    Q_UNUSED(localizedResourceName)
+}
+
+QString Utility::syncFolderDisplayName(const QString &folder, const QString &displayName)
+{
+    Q_UNUSED(folder)
+    Q_UNUSED(displayName)
+    return {};
+}
+
 void Utility::setLaunchOnStartup(const QString &appName, const QString &guiName, bool enable)
 {
     const auto userAutoStartPath = getUserAutostartDir();
@@ -99,7 +104,6 @@ void Utility::setLaunchOnStartup(const QString &appName, const QString &guiName,
         const QString executablePath = runningInsideAppImage ? appImagePath : QCoreApplication::applicationFilePath();
 
         QTextStream ts(&iniFile);
-        ts.setCodec("UTF-8");
         ts << QLatin1String("[Desktop Entry]\n")
            << QLatin1String("Name=") << guiName << QLatin1Char('\n')
            << QLatin1String("GenericName=") << QLatin1String("File Synchronizer\n")
