@@ -1,22 +1,10 @@
 /*
  * libcsync -- a library to sync a directory with another
  *
- * Copyright (c) 2008-2013 by Andreas Schneider <asn@cryptomilk.org>
- * Copyright (c) 2013- by Klaas Freitag <freitag@owncloud.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2013 ownCloud GmbH
+ * SPDX-FileCopyrightText: 2008-2013 by Andreas Schneider <asn@cryptomilk.org>
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include <cerrno>
@@ -52,8 +40,7 @@ struct csync_vio_handle_t {
 static int _csync_vio_local_stat_mb(const mbchar_t *wuri, csync_file_stat_t *buf);
 
 csync_vio_handle_t *csync_vio_local_opendir(const QString &name) {
-    QScopedPointer<csync_vio_handle_t> handle(new csync_vio_handle_t{});
-
+    auto handle = std::make_unique<csync_vio_handle_t>();
     auto dirname = QFile::encodeName(name);
 
     handle->dh = _topendir(dirname.constData());
@@ -62,7 +49,7 @@ csync_vio_handle_t *csync_vio_local_opendir(const QString &name) {
     }
 
     handle->path = dirname;
-    return handle.take();
+    return handle.release();
 }
 
 int csync_vio_local_closedir(csync_vio_handle_t *dhandle) {
