@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "accountstate.h"
@@ -78,7 +70,7 @@ AccountState::AccountState(const AccountPtr &account)
                 _termsOfServiceChecker.start();
             });
 
-    connect(this, &AccountState::isConnectedChanged, [=]{
+    connect(this, &AccountState::isConnectedChanged, [=, this]{
         // Get the Apps available on the server if we're now connected.
         if (isConnected()) {
             fetchNavigationApps();
@@ -554,7 +546,7 @@ void AccountState::slotEtagResponseHeaderReceived(const QByteArray &value, int s
 
 void AccountState::slotOcsError(int statusCode, const QString &message)
 {
-    qCDebug(lcAccountState) << "Error " << statusCode << " while fetching new navigation apps: " << message;
+    qCWarning(lcAccountState) << "Error " << statusCode << " while fetching new navigation apps: " << message;
 }
 
 void AccountState::slotCheckConnection()
