@@ -1,17 +1,7 @@
 /*
- * Copyright (C) by Duncan Mac-Vicar P. <duncan@kde.org>
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "application.h"
@@ -55,10 +45,6 @@
 #include "macOS/fileprovider.h"
 #endif
 
-#if defined(WITH_CRASHREPORTER)
-#include <libcrashreporter-handler/Handler.h>
-#endif
-
 #include <QLocale>
 #include <QTranslator>
 #include <QMenu>
@@ -97,11 +83,14 @@ namespace {
         "  --overridelocaldir         : specify a local dir to be used in the account setup wizard.\n"
         "  --userid                   : userId (username as on the server) to pass when creating an account via command-line.\n"
         "  --apppassword              : appPassword to pass when creating an account via command-line.\n"
+        "  --set-language <lang>      : specify a language to use for the client, regardless of the OS language.\n"
         "  --localdirpath             : (optional) path where to create a local sync folder when creating an account via command-line.\n"
         "  --isvfsenabled             : whether to set a VFS or non-VFS folder (1 for 'yes' or 0 for 'no') when creating an account via command-line.\n"
         "  --remotedirpath            : (optional) path to a remote subfolder when creating an account via command-line.\n"
         "  --serverurl                : a server URL to use when creating an account via command-line.\n"
+#if !DISABLE_ACCOUNT_MIGRATION
         "  --forcelegacyconfigimport  : forcefully import account configurations from legacy clients (if available).\n"
+#endif
         "  --reverse            : use a reverse layout direction.\n";
 
     QString applicationTrPath()
@@ -114,7 +103,7 @@ namespace {
         }
 #if defined(Q_OS_WIN)
         return QApplication::applicationDirPath() + QLatin1String("/i18n/");
-#elif defined(Q_OS_MAC)
+#elif defined(Q_OS_MACOS)
         return QApplication::applicationDirPath() + QLatin1String("/../Resources/Translations"); // path defaults to app dir.
 #elif defined(Q_OS_UNIX)
         if (qEnvironmentVariableIsSet("APPIMAGE")) {
@@ -304,9 +293,10 @@ Application::Application(int &argc, char **argv)
 
     if (_theme->doNotUseProxy()) {
         ConfigFile().setProxyType(QNetworkProxy::NoProxy);
-        for (const auto &accountState : AccountManager::instance()->accounts()) {
+        const auto &allAccounts = AccountManager::instance()->accounts();
+        for (const auto &accountState : allAccounts) {
             if (accountState && accountState->account()) {
-                accountState->account()->setNetworkProxySetting(Account::AccountNetworkProxySetting::GlobalProxy);
+                accountState->account()->setProxyType(QNetworkProxy::NoProxy);
             }
         }
     }
@@ -326,18 +316,6 @@ Application::Application(int &argc, char **argv)
         return;
     }
 
-#if defined(WITH_CRASHREPORTER)
-    if (ConfigFile().crashReporter()) {
-        auto reporter = QStringLiteral(CRASHREPORTER_EXECUTABLE);
-#ifdef Q_OS_WIN
-        if (!reporter.endsWith(QLatin1String(".exe"))) {
-            reporter.append(QLatin1String(".exe"));
-        }
-#endif
-        _crashHandler.reset(new CrashReporter::Handler(QDir::tempPath(), true, reporter));
-    }
-#endif
-
     setupLogging();
     setupTranslations();
 
@@ -362,6 +340,12 @@ Application::Application(int &argc, char **argv)
             shouldExit = true;
         }
 
+        if (!_setLanguage.isNull()) {
+            // checking for .isNull here as setting the value to an empty string will use the OS language again
+            cfg.setLanguage(_setLanguage);
+            shouldExit = true;
+        }
+
         if (AccountSetupCommandLineManager::instance()) {
             cfg.setVfsEnabled(AccountSetupCommandLineManager::instance()->isVfsEnabled());
         }
@@ -416,6 +400,16 @@ Application::Application(int &argc, char **argv)
     _gui->setupCloudProviders();
 #endif
 
+    if (_theme->doNotUseProxy()) {
+        ConfigFile().setProxyType(QNetworkProxy::NoProxy);
+        const auto &allAccounts = AccountManager::instance()->accounts();
+        for (const auto &accountState : allAccounts) {
+            if (accountState && accountState->account()) {
+                accountState->account()->setProxyType(QNetworkProxy::NoProxy);
+            }
+        }
+    }
+
     _proxy.setupQtProxyFromConfig(); // folders have to be defined first, than we set up the Qt proxy.
 
     connect(AccountManager::instance(), &AccountManager::accountAdded,
@@ -490,11 +484,11 @@ Application::~Application()
 void Application::setupAccountsAndFolders()
 {
     _folderManager.reset(new FolderMan);
-    FolderMan::instance()->setSyncEnabled(true);
 
     const auto accountsRestoreResult = restoreLegacyAccount();
 
     const auto foldersListSize = FolderMan::instance()->setupFolders();
+    FolderMan::instance()->setSyncEnabled(true);
 
     const auto prettyNamesList = [](const QList<AccountStatePtr> &accounts) {
         QStringList list;
@@ -881,9 +875,17 @@ void Application::parseOptions(const QStringList &options)
             } else {
                 showHint("Invalid URL passed to --overridelocaldir");
             }
-        } else if (option == QStringLiteral("--forcelegacyconfigimport")) {
+        } else if (option == QStringLiteral("--set-language")) {
+            if (it.hasNext() && !it.peekNext().startsWith(QLatin1String("--"))) {
+                _setLanguage = it.next();
+            }
+        }
+#if !DISABLE_ACCOUNT_MIGRATION
+        else if (option == QStringLiteral("--forcelegacyconfigimport")) {
             AccountManager::instance()->setForceLegacyImport(true);
-        } else {
+        }
+#endif
+        else {
             QString errorMessage;
             if (!AccountSetupCommandLineManager::instance()->parseCommandlineOption(option, it, errorMessage)) {
                 if (!errorMessage.isEmpty()) {
@@ -1001,10 +1003,22 @@ QString substLang(const QString &lang)
     return lang;
 }
 
+QString enforcedLanguage()
+{
+    const ConfigFile cfg;
+    const auto configLanguage = cfg.language();
+    if (!configLanguage.isEmpty()) {
+        // always prefer value from configuration
+        return configLanguage;
+    }
+
+    return Theme::instance()->enforcedLocale();
+}
+
 void Application::setupTranslations()
 {
     qCInfo(lcApplication) << "System UI languages are:" << QLocale::system().uiLanguages();
-    const auto enforcedLocale = Theme::instance()->enforcedLocale();
+    const auto enforcedLocale = enforcedLanguage();
     const auto lang = substLang(!enforcedLocale.isEmpty() ? enforcedLocale : QLocale::system().uiLanguages(QLocale::TagSeparator::Underscore).first());
     qCInfo(lcApplication) << "selected application language:" << lang;
 
