@@ -1,16 +1,6 @@
 /*
- * Copyright (C) by Olivier Goffart <ogoffart@woboq.com>
- * Copyright (C) by Michael Schuster <michael@schuster.ms>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -19,6 +9,8 @@
 #include <QTimer>
 #include "accountfwd.h"
 
+class QNetworkReply;
+
 namespace OCC {
 
 /**
@@ -71,6 +63,7 @@ private slots:
 
 private:
     void fetchNewToken(const TokenAction action);
+    [[nodiscard]] QJsonObject handleResponse(QNetworkReply *reply);
 
     Account *_account;
     QUrl _loginUrl;
