@@ -1,15 +1,6 @@
 /*
- * Copyright (C) 2022 by Claudio Cambra <claudio.cambra@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "sharemodel.h"
@@ -831,7 +822,7 @@ long long ShareModel::enforcedMaxExpireDateForShare(const SharePtr &share) const
 
     } else if ((share->getShareType() == Share::TypeUser ||
                 share->getShareType() == Share::TypeGroup ||
-                share->getShareType() == Share::TypeCircle ||
+                share->getShareType() == Share::TypeTeam ||
                 share->getShareType() == Share::TypeRoom) &&
                _accountState->account()->capabilities().shareInternalEnforceExpireDate()) {
         expireDays = _accountState->account()->capabilities().shareInternalExpireDateDays();
@@ -860,7 +851,7 @@ bool ShareModel::expireDateEnforcedForShare(const SharePtr &share) const
 
     } else if (share->getShareType() == Share::TypeUser ||
                share->getShareType() == Share::TypeGroup ||
-               share->getShareType() == Share::TypeCircle ||
+               share->getShareType() == Share::TypeTeam ||
                share->getShareType() == Share::TypeRoom) {
         return _accountState->account()->capabilities().shareInternalEnforceExpireDate();
 
