@@ -1,18 +1,9 @@
 /*
- * Copyright (C) by Duncan Mac-Vicar P. <duncan@kde.org>
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
+
 #include "common/syncjournaldb.h"
 #include "config.h"
 
@@ -178,7 +169,7 @@ bool Folder::checkLocalPath()
 {
     const QFileInfo fi(_definition.localPath);
     _canonicalLocalPath = fi.canonicalFilePath();
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     // Workaround QTBUG-55896  (Should be fixed in Qt 5.8)
     _canonicalLocalPath = _canonicalLocalPath.normalized(QString::NormalizationForm_C);
 #endif
@@ -223,6 +214,16 @@ QString Folder::shortGuiRemotePathOrAppName() const
     }
 }
 
+QString Folder::sidebarDisplayName() const
+{
+    auto displayName = shortGuiRemotePathOrAppName();
+    if (AccountManager::instance()->accounts().size() > 1) {
+        displayName = QStringLiteral("%1 - %2").arg(displayName, accountState()->account()->shortcutName());
+    }
+
+    return displayName;
+}
+
 QString Folder::alias() const
 {
     return _definition.alias;
@@ -523,9 +524,11 @@ void Folder::startVfs()
         return;
     }
 
+    const auto displayName = sidebarDisplayName();
+    qCDebug(lcFolder) << "Display name for VFS folder will be:" << displayName;
     VfsSetupParams vfsParams;
     vfsParams.filesystemPath = path();
-    vfsParams.displayName = shortGuiRemotePathOrAppName();
+    vfsParams.displayName = displayName;
     vfsParams.alias = alias();
     vfsParams.navigationPaneClsid = navigationPaneClsid().toString();
     vfsParams.remotePath = remotePathTrailingSlash();
@@ -629,7 +632,7 @@ void Folder::slotWatchedPathChanged(const QStringView &path, const ChangeReason
 // a sync operation, both for actual user files and the database
 // and log. Therefore we check notifications against operations
 // the sync is doing to filter out our own changes.
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 // On OSX the folder watcher does not report changes done by our
 // own process. Therefore nothing needs to be done here!
 #else
@@ -693,7 +696,8 @@ void Folder::slotFilesLockReleased(const QSet<QString> &files)
         SyncJournalFileRecord rec;
         const auto isFileRecordValid = journalDb()->getFileRecord(fileRecordPath, &rec) && rec.isValid();
         if (isFileRecordValid) {
-            [[maybe_unused]] const auto result = _vfs->updatePlaceholderMarkInSync(path() + rec.path(), rec._fileId);
+            const auto itemPointer = SyncFileItem::fromSyncJournalFileRecord(rec);
+            [[maybe_unused]] const auto result = _vfs->updatePlaceholderMarkInSync(path() + rec.path(), *itemPointer);
         }
         const auto canUnlockFile = isFileRecordValid
             && rec._lockstate._locked
@@ -737,7 +741,8 @@ void Folder::slotFilesLockImposed(const QSet<QString> &files)
         const auto fileRecordPath = fileFromLocalPath(file);
         SyncJournalFileRecord rec;
         if (journalDb()->getFileRecord(fileRecordPath, &rec) && rec.isValid()) {
-            [[maybe_unused]] const auto result = _vfs->updatePlaceholderMarkInSync(path() + rec.path(), rec._fileId);
+            const auto itemPointer = SyncFileItem::fromSyncJournalFileRecord(rec);
+            [[maybe_unused]] const auto result = _vfs->updatePlaceholderMarkInSync(path() + rec.path(), *itemPointer);
         }
     }
 }
@@ -762,10 +767,12 @@ void Folder::slotLockedFilesFound(const QSet<QString> &files)
         qCDebug(lcFolder) << "Automatically locking file on server" << remoteFilePath;
         _fileLockSuccess = connect(_accountState->account().data(), &Account::lockFileSuccess, this, [this, remoteFilePath] {
             disconnect(_fileLockSuccess);
+            disconnect(_fileLockFailure);
             qCDebug(lcFolder) << "Locking file succeeded" << remoteFilePath;
             startSync();
         });
         _fileLockFailure = connect(_accountState->account().data(), &Account::lockFileError, this, [this, remoteFilePath](const QString &message) {
+            disconnect(_fileLockSuccess);
             disconnect(_fileLockFailure);
             qCWarning(lcFolder) << "Failed to lock a file:" << remoteFilePath << message;
         });
@@ -1043,18 +1050,21 @@ void Folder::wipeForRemoval()
 {
     disconnectFolderWatcher();
 
+    // Delete files that have been partially downloaded.
+    slotDiscardDownloadProgress();
+
     // Unregister the socket API so it does not keep the .sync_journal file open
     FolderMan::instance()->socketApi()->slotUnregisterPath(alias());
-    _journal.close(); // close the sync journal
+    // Close the sync journal.  Do NOT call any methods that fetch data from it
+    // after this point, otherwise the journal is re-opened.  On some systems
+    // (Windows) this prevents the removal of the db file as it's open again...
+    _journal.close();
 
     if (!QDir(path()).exists()) {
         qCCritical(lcFolder) << "db files are not going to be deleted, sync folder could not be found at" << path();
         return;
     }
 
-    // Delete files that have been partially downloaded.
-    slotDiscardDownloadProgress();
-
     // Remove db and temporaries
     QString stateDbFile = _engine->journal()->databaseFilePath();
 
@@ -1209,27 +1219,21 @@ SyncOptions Folder::initializeSyncOptions() const
 void Folder::setDirtyNetworkLimits()
 {
     const auto account = _accountState->account();
-    const auto useGlobalDown = account->downloadLimitSetting() == Account::AccountNetworkTransferLimitSetting::GlobalLimit;
-    const auto useGlobalUp = account->uploadLimitSetting() == Account::AccountNetworkTransferLimitSetting::GlobalLimit;
 
     ConfigFile cfg;
 
     int downloadLimit = -75; // 75%
-    const auto useDownLimit = useGlobalDown 
-        ? cfg.useDownloadLimit() 
-        : static_cast<std::underlying_type_t<Account::AccountNetworkTransferLimitSetting>>(account->downloadLimitSetting());
+    const auto useDownLimit = static_cast<std::underlying_type_t<Account::AccountNetworkTransferLimitSetting>>(account->downloadLimitSetting());
     if (useDownLimit >= 1) {
-        downloadLimit = useGlobalDown ? cfg.downloadLimit() * 1000 : account->downloadLimit() * 1000;
+        downloadLimit = account->downloadLimit() * 1000;
     } else if (useDownLimit == 0) {
         downloadLimit = 0;
     }
 
     int uploadLimit = -75; // 75%
-    const auto useUpLimit = useGlobalUp 
-        ? cfg.useUploadLimit() 
-        : static_cast<std::underlying_type_t<Account::AccountNetworkTransferLimitSetting>>(account->uploadLimitSetting());
+    const auto useUpLimit = static_cast<std::underlying_type_t<Account::AccountNetworkTransferLimitSetting>>(account->uploadLimitSetting());
     if (useUpLimit >= 1) {
-        uploadLimit = useGlobalUp ? cfg.uploadLimit() * 1000 : account->uploadLimit() * 1000;
+        uploadLimit = account->uploadLimit() * 1000;
     } else if (useUpLimit == 0) {
         uploadLimit = 0;
     }
@@ -1712,7 +1716,7 @@ void Folder::disconnectFolderWatcher()
 
 bool Folder::virtualFilesEnabled() const
 {
-    return _definition.virtualFilesMode != Vfs::Off && !isVfsOnOffSwitchPending();
+    return _definition.virtualFilesMode != Vfs::Off && !isVfsOnOffSwitchPending() && !_vfs.isNull();
 }
 
 void Folder::slotAboutToRemoveAllFiles(SyncFileItem::Direction dir, std::function<void(bool)> callback)
