@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 // event masks
@@ -21,7 +13,7 @@
 
 #if defined(Q_OS_WIN)
 #include "folderwatcher_win.h"
-#elif defined(Q_OS_MAC)
+#elif defined(Q_OS_MACOS)
 #include "folderwatcher_mac.h"
 #elif defined(Q_OS_UNIX)
 #include "folderwatcher_linux.h"
@@ -93,7 +85,7 @@ void FolderWatcher::appendSubPaths(QDir dir, QStringList& subPaths) {
 
 void FolderWatcher::startNotificatonTest(const QString &path)
 {
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     // Testing the folder watcher on OSX is harder because the watcher
     // automatically discards changes that were performed by our process.
     // It would still be useful to test but the OSX implementation
