@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef MIRALL_GENERALSETTINGS_H
@@ -46,6 +38,9 @@ public slots:
     void slotStyleChanged();
 #if defined(BUILD_UPDATER)
     void loadUpdateChannelsList();
+    [[nodiscard]] QString updateChannelToLocalized(const QString &channel) const;
+    void setAndCheckNewUpdateChannel(const QString &newChannel);
+    void restoreUpdateChannel();
 #endif
 
 private slots:
@@ -54,6 +49,7 @@ private slots:
     void slotToggleOptionalServerNotifications(bool);
     void slotToggleChatNotifications(bool);
     void slotToggleCallNotifications(bool);
+    void slotToggleQuotaWarningNotifications(bool);
     void slotShowInExplorerNavigationPane(bool);
     void slotIgnoreFilesEditor();
     void slotCreateDebugArchive();
@@ -66,6 +62,7 @@ private slots:
     void slotUpdateChannelChanged();
     void slotUpdateCheckNow();
     void slotToggleAutoUpdateCheck();
+    void slotRestoreUpdateChannel();
 #endif
 
 private:
