@@ -1,18 +1,8 @@
 /*
- * Copyright (C) 2022 by Claudio Cambra <claudio.cambra@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-
 #include "fileprovider.h"
 
 #include <QLoggingCategory>
@@ -90,8 +80,8 @@ void FileProvider::configureXPC()
     _xpc = std::make_unique<FileProviderXPC>(new FileProviderXPC(this));
     if (_xpc) {
         qCInfo(lcMacFileProvider) << "Initialised file provider XPC.";
-        _xpc->connectToExtensions();
-        _xpc->configureExtensions();
+        _xpc->connectToFileProviderDomains();
+        _xpc->authenticateFileProviderDomains();
     } else {
         qCWarning(lcMacFileProvider) << "Could not initialise file provider XPC.";
     }
@@ -102,5 +92,15 @@ FileProviderXPC *FileProvider::xpc() const
     return _xpc.get();
 }
 
+FileProviderDomainManager *FileProvider::domainManager() const
+{
+    return _domainManager.get();
+}
+
+FileProviderSocketServer *FileProvider::socketServer() const
+{
+    return _socketServer.get();
+}
+
 } // namespace Mac
 } // namespace OCC
