@@ -1,15 +1,6 @@
 /*
- * Copyright (C) 2023 by Claudio Cambra <claudio.cambra@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <QLoggingCategory>
@@ -28,7 +19,12 @@ NSArray<NSDictionary<NSFileProviderServiceName, NSFileProviderService *> *> *get
 NSArray<NSXPCConnection *> *connectToFileProviderServices(NSArray<NSDictionary<NSFileProviderServiceName, NSFileProviderService *> *> *fpServices);
 void configureFileProviderConnection(NSXPCConnection *connection);
 NSObject *getRemoteServiceObject(NSXPCConnection *connection, Protocol *protocol);
-NSString *getExtensionAccountId(NSObject<ClientCommunicationProtocol> *clientCommService);
-QHash<QString, void*> processClientCommunicationConnections(NSArray *connections);
 
-}
\ No newline at end of file
+/**
+ * @brief Get the domain identifier for and from a given client communication service.
+ */
+NSString *getFileProviderDomainIdentifier(NSObject<ClientCommunicationProtocol> *clientCommService);
+
+QHash<QString, void*> processClientCommunicationConnections(NSArray<NSXPCConnection *> *connections);
+
+}
