@@ -1,16 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- * Copyright (C) by Krzesimir Nowak <krzesimir@endocode.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2012 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "accessmanager.h"
@@ -28,6 +19,7 @@
 #include "sslerrordialog.h"
 #include "wizard/owncloudwizard.h"
 #include "wizard/owncloudwizardcommon.h"
+#include "account.h"
 
 #include "creds/credentialsfactory.h"
 #include "creds/abstractcredentials.h"
@@ -35,6 +27,7 @@
 
 #ifdef BUILD_FILE_PROVIDER_MODULE
 #include "gui/macOS/fileprovider.h"
+#include "gui/macOS/fileprovidersettingscontroller.h"
 #endif
 
 #include <QAbstractButton>
@@ -154,20 +147,34 @@ void OwncloudSetupWizard::startWizard()
 }
 
 // also checks if an installation is valid and determines auth type in a second step
-void OwncloudSetupWizard::slotCheckServer(const QString &urlString)
+void OwncloudSetupWizard::slotCheckServer(const QUrl &serverURL, const OCC::WizardProxySettingsDialog::WizardProxySettings &proxySettings)
 {
-    QString fixedUrl = urlString;
-    QUrl url = QUrl::fromUserInput(fixedUrl);
-    // fromUserInput defaults to http, not http if no scheme is specified
-    if (!fixedUrl.startsWith("http://") && !fixedUrl.startsWith("https://")) {
-        url.setScheme("https");
-    }
     AccountPtr account = _ocWizard->account();
-    account->setUrl(url);
+    account->setUrl(serverURL);
 
-    // Reset the proxy which might had been determined previously in ConnectionValidator::checkServerAndAuth()
-    // when there was a previous account.
-    account->networkAccessManager()->setProxy(QNetworkProxy(QNetworkProxy::NoProxy));
+    account->setProxyType(proxySettings._proxyType);
+    switch (proxySettings._proxyType)
+    {
+    case QNetworkProxy::HttpCachingProxy:
+    case QNetworkProxy::FtpCachingProxy:
+    case QNetworkProxy::NoProxy:
+    case QNetworkProxy::ProxyType::DefaultProxy:
+        // Reset the proxy which might had been determined previously in ConnectionValidator::checkServerAndAuth()
+        // when there was a previous account.
+        account->networkAccessManager()->setProxy({QNetworkProxy::NoProxy});
+        break;
+    case QNetworkProxy::Socks5Proxy:
+    case QNetworkProxy::HttpProxy:
+        account->setProxyHostName(proxySettings._host);
+        account->setProxyPort(proxySettings._port);
+        account->setProxyNeedsAuth(proxySettings._needsAuth == WizardProxySettingsDialog::ProxyAuthentication::AuthenticationRequired);
+        if (account->proxyNeedsAuth()) {
+            account->setProxyUser(proxySettings._user);
+            account->setProxyPassword(proxySettings._password);
+        }
+
+        break;
+    }
 
     // And also reset the QSslConfiguration, for the same reason (#6832)
     // Here the client certificate is added, if any. Later it'll be in HttpCredentials
@@ -187,8 +194,7 @@ void OwncloudSetupWizard::slotCheckServer(const QString &urlString)
     account->networkAccessManager()->clearAccessCache();
 
     // Lookup system proxy in a thread https://github.com/owncloud/client/issues/2993
-    if ((ClientProxy::isUsingSystemDefault() && account->networkProxySetting() == Account::AccountNetworkProxySetting::GlobalProxy)
-        || account->proxyType() == QNetworkProxy::DefaultProxy) {
+    if (ClientProxy::isUsingSystemDefault() || account->proxyType() == QNetworkProxy::DefaultProxy) {
         qCDebug(lcWizard) << "Trying to look up system proxy";
         ClientProxy::lookupSystemProxyAsync(account->url(), this, SLOT(slotSystemProxyLookupDone(QNetworkProxy)));
     } else {
@@ -295,7 +301,11 @@ void OwncloudSetupWizard::slotFoundServer(const QUrl &url, const QJsonObject &in
         qCInfo(lcWizard) << " was redirected to" << url.toString();
     }
 
-    slotDetermineAuthType();
+    if (_ocWizard->account()->isPublicShareLink()) {
+        _ocWizard->setAuthType(DetermineAuthTypeJob::Basic);
+    } else {
+        slotDetermineAuthType();
+    }
 }
 
 void OwncloudSetupWizard::slotNoServerFound(QNetworkReply *reply)
@@ -347,6 +357,19 @@ void OwncloudSetupWizard::slotConnectToOCUrl(const QString &url)
         creds->persist();
     }
 
+    if (_ocWizard->account()->isPublicShareLink()) {
+        _ocWizard->account()->setDavUser(creds->user());
+        _ocWizard->account()->setDavDisplayName(creds->user());
+
+        _ocWizard->setField(QLatin1String("OCUrl"), url);
+        _ocWizard->appendToConfigurationLog(tr("Trying to connect to %1 at %2 …")
+                                                .arg(Theme::instance()->appNameGUI())
+                                                .arg(url));
+
+        testOwnCloudConnect();
+        return;
+    }
+
     const auto fetchUserNameJob = new JsonApiJob(_ocWizard->account()->sharedFromThis(), QStringLiteral("/ocs/v1.php/cloud/user"));
     connect(fetchUserNameJob, &JsonApiJob::jsonReceived, this, [this, url](const QJsonDocument &json, int statusCode) {
         if (statusCode != 100) {
@@ -488,6 +511,14 @@ bool OwncloudSetupWizard::checkDowngradeAdvised(QNetworkReply *reply)
 
 void OwncloudSetupWizard::slotCreateLocalAndRemoteFolders(const QString &localFolder, const QString &remoteFolder)
 {
+#ifdef BUILD_FILE_PROVIDER_MODULE
+    if (Mac::FileProvider::fileProviderAvailable() && _ocWizard->useVirtualFileSync()) {
+        qCInfo(lcWizard) << "Not creating local/remote folders as because macOS File Provider uses its own sync root";
+        finalizeSetup(true);
+        return;
+    }
+#endif
+
     qCInfo(lcWizard) << "Setup local sync folder for new oC connection " << localFolder;
     const QDir fi(localFolder);
 
@@ -602,7 +633,7 @@ void OwncloudSetupWizard::createRemoteFolder()
 void OwncloudSetupWizard::slotCreateRemoteFolderFinished(QNetworkReply *reply)
 {
     auto error = reply->error();
-    qCDebug(lcWizard) << "** webdav mkdir request finished " << error;
+    qCWarning(lcWizard) << "** webdav mkdir request finished " << error;
     //    disconnect(ownCloudInfo::instance(), SIGNAL(webdavColCreated(QNetworkReply::NetworkError)),
     //               this, SLOT(slotCreateRemoteFolderFinished(QNetworkReply::NetworkError)));
 
@@ -690,20 +721,16 @@ void OwncloudSetupWizard::slotAssistantFinished(int result)
         auto account = applyAccountChanges();
 
 #ifdef BUILD_FILE_PROVIDER_MODULE
-        if (Mac::FileProvider::fileProviderAvailable()) {
+        if (_ocWizard->useVirtualFileSyncByDefault()) {
             Mac::FileProvider::instance()->domainManager()->addFileProviderDomainForAccount(account);
+            auto const accountId = account->account()->userIdAtHostWithPort();
+            // let the user settings know that VFS is enabled
+            Mac::FileProviderSettingsController::instance()->setVfsEnabledForAccount(accountId, true, false);
             _ocWizard->appendToConfigurationLog(
-                tr("<font color=\"green\"><b>File Provider-based account %1 successfully created!</b></font>").arg(account->account()->userIdAtHostWithPort()));
+                tr("<font color=\"green\"><b>File Provider-based account %1 successfully created!</b></font>").arg(accountId));
             _ocWizard->done(result);
             emit ownCloudWizardDone(result);
 
-            QMessageBox::information(nullptr,
-                                     tr("Virtual files enabled"),
-                                     tr("Your account is now syncing with virtual files support. "
-                                        "This means that all your files are online-only by default, "
-                                        "and will be downloaded on-demand when you open them. "
-                                        "You may find your files under the <b>Locations</b> section of the Finder sidebar."));
-
             return;
         }
 #endif
@@ -777,7 +804,13 @@ AccountState *OwncloudSetupWizard::applyAccountChanges()
     auto manager = AccountManager::instance();
 
     auto newState = manager->addAccount(newAccount);
+
+    if (newAccount->isPublicShareLink()) {
+        qCInfo(lcWizard()) << "setting up public share link account";
+    }
+
     manager->saveAccount(newAccount);
+
     return newState;
 }
 
