@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Roeland Jago Douma <roeland@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2015 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "sharee.h"
@@ -49,8 +41,8 @@ QString Sharee::format() const
         formatted += QLatin1String(" (email)");
     } else if (_type == Type::Federated) {
         formatted += QLatin1String(" (remote)");
-    } else if (_type == Type::Circle) {
-        formatted += QLatin1String(" (circle)");
+    } else if (_type == Type::Team) {
+        formatted += QLatin1String(" (team)");
     } else if (_type == Type::Room) {
         formatted += QLatin1String(" (conversation)");
     }
