@@ -1,16 +1,9 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2012 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
+
 #include "configfile.h"
 #include "sslerrordialog.h"
 #include "theme.h"
@@ -39,6 +32,27 @@ bool SslDialogErrorHandler::handleErrors(QList<QSslError> errors, const QSslConf
         return false;
     }
 
+    if (!account) {
+        return false;
+    }
+
+    // Check if HSTS is active for this host
+    auto qnam = account->networkAccessManager();
+    if (qnam && qnam->isStrictTransportSecurityEnabled()) {
+        // Get the host from the account URL
+        QString host = account->url().host();
+
+        // Check if this host has an active HSTS policy
+        auto hstsPolicies = qnam->strictTransportSecurityHosts();
+        for (const auto &policy : std::as_const(hstsPolicies)) {
+            if (policy.host() == host && !policy.isExpired()) {
+                // HSTS is active for this host, don't show the dialog
+                qCInfo(lcSslErrorDialog) << "SSL certificate error, but HSTS is active. Rejecting connection.";
+                return false;
+            }
+        }
+    }
+
     SslErrorDialog dlg(account);
     // whether the failing certs have previously been accepted
     if (dlg.checkFailingCertsKnown(errors)) {
@@ -138,7 +152,7 @@ bool SslErrorDialog::checkFailingCertsKnown(const QList<QSslError> &errors)
     msg += QL("<h3>") + tr("Cannot connect securely to <i>%1</i>:").arg(host) + QL("</h3>");
     // loop over the unknown certs and line up their errors.
     msg += QL("<div id=\"ca_errors\">");
-    for (const auto &cert : _unknownCerts) {
+    for (const auto &cert : std::as_const(_unknownCerts)) {
         msg += QL("<div id=\"ca_error\">");
         // add the errors for this cert
         for (const auto &err : errors) {
