@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Cédric Bellegarde <gnumdk@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2013 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef SYSTRAY_H
@@ -89,12 +81,12 @@ public:
     enum class FileDetailsPage { Activity, Sharing };
     Q_ENUM(FileDetailsPage);
 
-    Q_REQUIRED_RESULT QString windowTitle() const;
-    Q_REQUIRED_RESULT bool useNormalWindow() const;
+    [[nodiscard]] QString windowTitle() const;
+    [[nodiscard]] bool useNormalWindow() const;
 
-    Q_REQUIRED_RESULT bool syncIsPaused() const;
-    Q_REQUIRED_RESULT bool anySyncFolders() const;
-    Q_REQUIRED_RESULT bool isOpen() const;
+    [[nodiscard]] bool syncIsPaused() const;
+    [[nodiscard]] bool anySyncFolders() const;
+    [[nodiscard]] bool isOpen() const;
 
     [[nodiscard]] bool enableAddAccount() const;
 
@@ -195,7 +187,7 @@ private:
 
     AccessManagerFactory _accessManagerFactory;
 
-    QSet<qlonglong> _callsAlreadyNotified;
+    QSet<qint64> _callsAlreadyNotified;
     QPointer<QObject> _editFileLocallyLoadingDialog;
     QPointer<QObject> _encryptionTokenDiscoveryDialog;
     QVector<QQuickWindow*> _fileDetailDialogs;
