@@ -1,15 +1,6 @@
 /*
- * Copyright (C) by Felix Weilbach <felix.weilbach@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "syncstatussummary.h"
@@ -21,6 +12,12 @@
 #include "syncresult.h"
 #include "tray/usermodel.h"
 
+#ifdef BUILD_FILE_PROVIDER_MODULE
+#include "gui/macOS/fileprovider.h"
+#include "gui/macOS/fileprovidersocketserver.h"
+#include "gui/macOS/fileprovidersettingscontroller.h"
+#endif
+
 #include <theme.h>
 
 namespace {
@@ -51,6 +48,9 @@ SyncStatusSummary::SyncStatusSummary(QObject *parent)
     const auto folderMan = FolderMan::instance();
     connect(folderMan, &FolderMan::folderListChanged, this, &SyncStatusSummary::onFolderListChanged);
     connect(folderMan, &FolderMan::folderSyncStateChange, this, &SyncStatusSummary::onFolderSyncStateChanged);
+#ifdef BUILD_FILE_PROVIDER_MODULE
+    connect(Mac::FileProvider::instance()->socketServer(), &Mac::FileProviderSocketServer::syncStateChanged, this, &SyncStatusSummary::onFileProviderDomainSyncStateChanged);
+#endif
 }
 
 bool SyncStatusSummary::reloadNeeded(AccountState *accountState) const
@@ -105,7 +105,7 @@ void SyncStatusSummary::markFolderAsSuccess(const Folder *folder)
 
 bool SyncStatusSummary::folderErrors() const
 {
-    return _foldersWithErrors.size() != 0;
+    return !_foldersWithErrors.empty();
 }
 
 bool SyncStatusSummary::folderError(const Folder *folder) const
@@ -125,23 +125,60 @@ void SyncStatusSummary::setSyncStateForFolder(const Folder *folder)
         setTotalFiles(0);
         setSyncStatusString(tr("Offline"));
         setSyncStatusDetailString("");
+        if (_accountState->state() == AccountState::NeedToSignTermsOfService) {
+            setSyncStatusDetailString(tr("You need to accept the terms of service"));
+        }
         setSyncIcon(Theme::instance()->folderOffline());
         return;
     }
 
     const auto state = determineSyncStatus(folder->syncResult());
 
+    switch (state) {
+    case SyncResult::Success:
+    case SyncResult::SyncPrepare:
+        markFolderAsSuccess(folder);
+        break;
+    case SyncResult::Error:
+    case SyncResult::SetupError:
+    case SyncResult::Problem:
+    case SyncResult::Undefined:
+        markFolderAsError(folder);
+    case SyncResult::SyncRunning:
+    case SyncResult::NotYetStarted:
+    case SyncResult::Paused:
+    case SyncResult::SyncAbortRequested:
+        break;
+    }
+
+    setSyncState(state);
+}
+
+void SyncStatusSummary::setSyncState(const SyncResult::Status state)
+{
+    if (_accountState && !_accountState->isConnected()) {
+        setSyncing(false);
+        setTotalFiles(0);
+        setSyncStatusString(tr("Offline"));
+        setSyncStatusDetailString("");
+        setSyncIcon(Theme::instance()->offline());
+        return;
+    }
+
     switch (state) {
     case SyncResult::Success:
     case SyncResult::SyncPrepare:
         // Success should only be shown if all folders were fine
-        if (!folderErrors() || folderError(folder)) {
+        if (!folderErrors()
+#ifdef BUILD_FILE_PROVIDER_MODULE
+            && _fileProviderDomainsWithErrors.empty()
+#endif
+        ) {
             setSyncing(false);
             setTotalFiles(0);
             setSyncStatusString(tr("All synced!"));
             setSyncStatusDetailString("");
-            setSyncIcon(Theme::instance()->syncStatusOk());
-            markFolderAsSuccess(folder);
+            setSyncIcon(Theme::instance()->ok());
         }
         break;
     case SyncResult::Error:
@@ -150,8 +187,7 @@ void SyncStatusSummary::setSyncStateForFolder(const Folder *folder)
         setTotalFiles(0);
         setSyncStatusString(tr("Some files couldn't be synced!"));
         setSyncStatusDetailString(tr("See below for errors"));
-        setSyncIcon(Theme::instance()->syncStatusError());
-        markFolderAsError(folder);
+        setSyncIcon(Theme::instance()->error());
         break;
     case SyncResult::SyncRunning:
     case SyncResult::NotYetStarted:
@@ -162,7 +198,7 @@ void SyncStatusSummary::setSyncStateForFolder(const Folder *folder)
             setSyncStatusString(tr("Syncing changes"));
         }
         setSyncStatusDetailString("");
-        setSyncIcon(Theme::instance()->syncStatusRunning());
+        setSyncIcon(Theme::instance()->sync());
         break;
     case SyncResult::Paused:
     case SyncResult::SyncAbortRequested:
@@ -170,7 +206,7 @@ void SyncStatusSummary::setSyncStateForFolder(const Folder *folder)
         setTotalFiles(0);
         setSyncStatusString(tr("Sync paused"));
         setSyncStatusDetailString("");
-        setSyncIcon(Theme::instance()->syncStatusPause());
+        setSyncIcon(Theme::instance()->pause());
         break;
     case SyncResult::Problem:
     case SyncResult::Undefined:
@@ -178,8 +214,7 @@ void SyncStatusSummary::setSyncStateForFolder(const Folder *folder)
         setTotalFiles(0);
         setSyncStatusString(tr("Some files could not be synced!"));
         setSyncStatusDetailString(tr("See below for warnings"));
-        setSyncIcon(Theme::instance()->syncStatusWarning());
-        markFolderAsError(folder);
+        setSyncIcon(Theme::instance()->warning());
         break;
     }
 }
@@ -197,6 +232,35 @@ void SyncStatusSummary::onFolderSyncStateChanged(const Folder *folder)
     setSyncStateForFolder(folder);
 }
 
+#ifdef BUILD_FILE_PROVIDER_MODULE
+void SyncStatusSummary::onFileProviderDomainSyncStateChanged(const AccountPtr &account, SyncResult::Status state)
+{
+    if (!_accountState || !_accountState->isConnected() || account != _accountState->account()) {
+        return;
+    }
+
+    switch (state) {
+    case SyncResult::Success:
+    case SyncResult::SyncPrepare:
+        // Success should only be shown if all folders were fine
+        _fileProviderDomainsWithErrors.erase(account->userIdAtHostWithPort());
+        break;
+    case SyncResult::Error:
+    case SyncResult::SetupError:
+    case SyncResult::Problem:
+    case SyncResult::Undefined:
+        _fileProviderDomainsWithErrors.insert(account->userIdAtHostWithPort());
+    case SyncResult::SyncRunning:
+    case SyncResult::NotYetStarted:
+    case SyncResult::Paused:
+    case SyncResult::SyncAbortRequested:
+        break;
+    }
+        
+    setSyncState(state);
+}
+#endif
+
 constexpr double calculateOverallPercent(
     qint64 totalFileCount, qint64 completedFile, qint64 totalSize, qint64 completedSize)
 {
@@ -369,6 +433,18 @@ void SyncStatusSummary::initSyncState()
         syncStateFallbackNeeded = false;
     }
 
+#ifdef BUILD_FILE_PROVIDER_MODULE
+    if (Mac::FileProvider::fileProviderAvailable() && _accountState) {
+        const auto account = _accountState->account();
+        const auto userIdAtHostWithPort = account->userIdAtHostWithPort();
+        if (Mac::FileProviderSettingsController::instance()->vfsEnabledForAccount(userIdAtHostWithPort)) {
+            const auto lastKnownSyncState = Mac::FileProvider::instance()->socketServer()->latestReceivedSyncStatusForAccount(account);
+            onFileProviderDomainSyncStateChanged(account, lastKnownSyncState);
+            syncStateFallbackNeeded = false;
+        }
+    }
+#endif
+
     if (syncStateFallbackNeeded) {
         setSyncStateToConnectedState();
     }
