@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "creds/abstractcredentials.h"
@@ -34,4 +26,21 @@ void AbstractCredentialsWizardPage::cleanupPage()
         }
     }
 }
+
+int AbstractCredentialsWizardPage::nextId() const
+{
+    const auto ocWizard = qobject_cast<OwncloudWizard *>(wizard());
+    Q_ASSERT(ocWizard);
+
+    if (ocWizard->needsToAcceptTermsOfService()) {
+        return WizardCommon::Page_TermsOfService;
+    }
+
+    if (ocWizard->useVirtualFileSyncByDefault()) {
+        return -1;
+    }
+
+    return WizardCommon::Page_AdvancedSetup;
+}
+
 }
