@@ -1,16 +1,6 @@
 /*
- * Copyright (C) by Olivier Goffart <ogoffart@woboq.com>
- * Copyright (C) by Michael Schuster <michael@schuster.ms>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -42,7 +32,6 @@ public:
 
     void initializePage() override;
     void cleanupPage() override;
-    [[nodiscard]] int nextId() const override;
     void setConnected();
     [[nodiscard]] bool isComplete() const override;
 
@@ -51,7 +40,7 @@ public Q_SLOTS:
     void slotPollNow();
     void slotStyleChanged();
 
-signals:
+Q_SIGNALS:
     void connectToOCUrl(const QString &);
     void pollNow();
     void styleChanged();
