@@ -1,16 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- * Copyright (C) by Krzesimir Nowak <krzesimir@endocode.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef MIRALL_OWNCLOUD_SETUP_PAGE_H
@@ -18,16 +9,13 @@
 
 #include <QWizard>
 
-#include "wizard/owncloudwizardcommon.h"
 #include "wizard/owncloudwizard.h"
 
 #include "../addcertificatedialog.h"
-#include "wizard/owncloudconnectionmethoddialog.h"
+#include "wizard/wizardproxysettingsdialog.h"
 
 #include "ui_owncloudsetupnocredspage.h"
 
-#include "config.h"
-
 class QLabel;
 class QVariant;
 class QProgressIndicator;
@@ -68,16 +56,23 @@ protected slots:
     void slotUrlChanged(const QString &);
     void slotUrlEditFinished();
 
+    void slotSetProxySettings();
+
     void setupCustomization();
 
 signals:
-    void determineAuthType(const QString &);
+    void determineAuthType(const QUrl &serverURL, const OCC::WizardProxySettingsDialog::WizardProxySettings &proxySettings);
 
 private:
     void setLogo();
     void customizeStyle();
     void setupServerAddressDescriptionLabel();
 
+    void setProxySettingsButtonEnabled(bool enable);
+    void setProxySettingsButtonVisible(bool visible);
+    [[nodiscard]] QAbstractButton* getProxySettingsButton() const;
+    void ensureProxySettingsButtonIsConnected();
+
     Ui_OwncloudSetupPage _ui{};
 
     QString _oCUrl;
@@ -90,6 +85,10 @@ private:
     OwncloudWizard *_ocWizard;
     AddCertificateDialog *addCertDial = nullptr;
 
+    WizardProxySettingsDialog *_proxySettingsDialog = nullptr;
+    WizardProxySettingsDialog::WizardProxySettings _proxySettings;
+    QMetaObject::Connection _proxyButtonIsConnected;
+
     // Grab the forceLoginV2-setting from the wizard
     bool useFlow2 = _ocWizard->useFlow2();
 };
