@@ -1,3 +1,8 @@
+/*
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
 #include "webviewpage.h"
 
 #include <QWebEngineUrlRequestJob>
@@ -26,7 +31,7 @@ WebViewPage::WebViewPage(QWidget *parent)
     _webView = new WebView(this);
 
     auto *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(_webView, 1);
     setLayout(layout);
 
@@ -91,10 +96,6 @@ void WebViewPage::cleanupPage()
     _ocWizard->centerWindow();
 }
 
-int WebViewPage::nextId() const {
-    return WizardCommon::Page_AdvancedSetup;
-}
-
 bool WebViewPage::isComplete() const {
     return false;
 }
