@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Daniel Molkentin <danimo@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2013 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "account.h"
@@ -17,6 +9,7 @@
 #include "accountfwd.h"
 #include "capabilities.h"
 #include "clientsideencryptionjobs.h"
+#include "common/utility.h"
 #include "configfile.h"
 #include "cookiejar.h"
 #include "creds/abstractcredentials.h"
@@ -76,6 +69,7 @@ Account::Account(QObject *parent)
     : QObject(parent)
     , _capabilities(QVariantMap())
     , _serverColor(Theme::defaultColor())
+    , _e2e{}
 {
     qRegisterMetaType<AccountPtr>("AccountPtr");
     qRegisterMetaType<Account *>("Account*");
@@ -109,7 +103,11 @@ QString Account::davPath() const
 
 QString Account::davPathRoot() const
 {
-    return davPathBase() + QLatin1Char('/') + davUser();
+    if (_isPublicLink) {
+        return QStringLiteral("/public.php/webdav");
+    } else {
+        return davPathBase() + QLatin1Char('/') + davUser();
+    }
 }
 
 void Account::setSharedThis(AccountPtr sharedThis)
@@ -150,6 +148,11 @@ void Account::setDavUser(const QString &newDavUser)
     emit prettyNameChanged();
 }
 
+QString Account::userFromCredentials() const
+{
+    return _credentials ? _credentials->user() : QString{};
+}
+
 #ifndef TOKEN_AUTH_ONLY
 QImage Account::avatar() const
 {
@@ -179,6 +182,21 @@ QString Account::displayName() const
     return displayName;
 }
 
+QString Account::shortcutName() const
+{
+    auto url_part = _url.host();
+    const auto port = url().port();
+    if (port > 0 && port != 80 && port != 443) {
+        url_part.append(QLatin1Char(':'));
+        url_part.append(QString::number(port));
+    }
+
+    auto shortcutName = QStringLiteral("%1 - %2").arg(url_part, prettyName());
+
+
+    return shortcutName;
+}
+
 QString Account::userIdAtHostWithPort() const
 {
     QString dn = QStringLiteral("%1@%2").arg(_davUser, _url.host());
@@ -205,7 +223,7 @@ void Account::setDavDisplayName(const QString &newDisplayName)
 QString Account::prettyName() const
 {
     // If davDisplayName is empty (can be several reasons, simplest is missing login at startup), fall back to username
-    auto name = davDisplayName();
+    auto name = isPublicShareLink() ? tr("Public Share Link") : davDisplayName();
 
     if (name.isEmpty()) {
         name = davUser();
@@ -416,17 +434,20 @@ void Account::resetNetworkAccessManager()
         this, &Account::proxyAuthenticationRequired);
 }
 
-QNetworkAccessManager *Account::networkAccessManager()
+QNetworkAccessManager *Account::networkAccessManager() const
 {
     return _networkAccessManager.data();
 }
 
-QSharedPointer<QNetworkAccessManager> Account::sharedNetworkAccessManager()
+QSharedPointer<QNetworkAccessManager> Account::sharedNetworkAccessManager() const
 {
     return _networkAccessManager;
 }
 
-QNetworkReply *Account::sendRawRequest(const QByteArray &verb, const QUrl &url, QNetworkRequest req, QIODevice *data)
+QNetworkReply *Account::sendRawRequest(const QByteArray &verb,
+                                       const QUrl &url,
+                                       QNetworkRequest req,
+                                       QIODevice *data)
 {
     req.setUrl(url);
     req.setSslConfiguration(this->getOrCreateSslConfig());
@@ -444,7 +465,10 @@ QNetworkReply *Account::sendRawRequest(const QByteArray &verb, const QUrl &url,
     return _networkAccessManager->sendCustomRequest(req, verb, data);
 }
 
-QNetworkReply *Account::sendRawRequest(const QByteArray &verb, const QUrl &url, QNetworkRequest req, const QByteArray &data)
+QNetworkReply *Account::sendRawRequest(const QByteArray &verb,
+                                       const QUrl &url,
+                                       QNetworkRequest req,
+                                       const QByteArray &data)
 {
     req.setUrl(url);
     req.setSslConfiguration(this->getOrCreateSslConfig());
@@ -462,7 +486,10 @@ QNetworkReply *Account::sendRawRequest(const QByteArray &verb, const QUrl &url,
     return _networkAccessManager->sendCustomRequest(req, verb, data);
 }
 
-QNetworkReply *Account::sendRawRequest(const QByteArray &verb, const QUrl &url, QNetworkRequest req, QHttpMultiPart *data)
+QNetworkReply *Account::sendRawRequest(const QByteArray &verb,
+                                       const QUrl &url,
+                                       QNetworkRequest req,
+                                       QHttpMultiPart *data)
 {
     req.setUrl(url);
     req.setSslConfiguration(this->getOrCreateSslConfig());
@@ -531,10 +558,26 @@ void Account::setSslErrorHandler(AbstractSslErrorHandler *handler)
 
 void Account::setUrl(const QUrl &url)
 {
-    _url = url;
+    const QRegularExpression discoverPublicLinks(R"(((https|http)://[^/]*).*/s/([^/]*)$)");
+    const auto isPublicLink = discoverPublicLinks.match(url.toString());
+    if (isPublicLink.hasMatch()) {
+        _url = QUrl::fromUserInput(isPublicLink.captured(1));
+        _url.setUserName(isPublicLink.captured(3));
+        setDavUser(isPublicLink.captured(3));
+        _isPublicLink = true;
+        _publicShareLinkUrl = url;
+    } else {
+        _url = url;
+    }
+
     _userVisibleUrl = url;
 }
 
+QUrl Account::publicShareLinkUrl() const
+{
+    return _publicShareLinkUrl;
+}
+
 void Account::setUserVisibleHost(const QString &host)
 {
     _userVisibleUrl.setHost(host);
@@ -624,7 +667,7 @@ void Account::slotHandleSslErrors(QNetworkReply *reply, QList<QSslError> errors)
             return;
 
         // Mark all involved certificates as rejected, so we don't ask the user again.
-        for (const auto &error : errors) {
+        for (const auto &error : std::as_const(errors)) {
             if (!_rejectedCertificates.contains(error.certificate())) {
                 _rejectedCertificates.append(error.certificate());
             }
@@ -944,7 +987,8 @@ void Account::slotDirectEditingRecieved(const QJsonDocument &json)
     auto data = json.object().value("ocs").toObject().value("data").toObject();
     const auto editors = data.value("editors").toObject();
 
-    for (const auto &editorKey : editors.keys()) {
+    const auto &allKeys = editors.keys();
+    for (const auto &editorKey : allKeys) {
         auto editor = editors.value(editorKey).toObject();
 
         const QString id = editor.value("id").toString();
@@ -956,11 +1000,11 @@ void Account::slotDirectEditingRecieved(const QJsonDocument &json)
 
             auto *directEditor = new DirectEditor(id, name);
 
-            for (const auto &mimeType : mimeTypes) {
+            for (const auto &mimeType : std::as_const(mimeTypes)) {
                 directEditor->addMimetype(mimeType.toString().toLatin1());
             }
 
-            for (const auto &optionalMimeType : optionalMimeTypes) {
+            for (const auto &optionalMimeType : std::as_const(optionalMimeTypes)) {
                 directEditor->addOptionalMimetype(optionalMimeType.toString().toLatin1());
             }
 
@@ -1044,19 +1088,19 @@ bool Account::fileCanBeUnlocked(SyncJournalDb * const journal,
     SyncJournalFileRecord record;
     if (journal->getFileRecord(folderRelativePath, &record)) {
         if (record._lockstate._lockOwnerType == static_cast<int>(SyncFileItem::LockOwnerType::AppLock)) {
-            qCDebug(lcAccount()) << folderRelativePath << "cannot be unlocked: app lock";
+            qCWarning(lcAccount()) << folderRelativePath << "cannot be unlocked: app lock";
             return false;
         }
 
         if (record._lockstate._lockOwnerType == static_cast<int>(SyncFileItem::LockOwnerType::UserLock) &&
             record._lockstate._lockOwnerId != sharedFromThis()->davUser()) {
-            qCDebug(lcAccount()) << folderRelativePath << "cannot be unlocked: user lock from" << record._lockstate._lockOwnerId;
+            qCWarning(lcAccount()) << folderRelativePath << "cannot be unlocked: user lock from" << record._lockstate._lockOwnerId;
             return false;
         }
 
         if (record._lockstate._lockOwnerType == static_cast<int>(SyncFileItem::LockOwnerType::TokenLock) &&
             record._lockstate._lockToken.isEmpty()) {
-            qCDebug(lcAccount()) << folderRelativePath << "cannot be unlocked: token lock without known token";
+            qCWarning(lcAccount()) << folderRelativePath << "cannot be unlocked: token lock without known token";
             return false;
         }
 
@@ -1131,6 +1175,85 @@ void Account::setAskUserForMnemonic(const bool ask)
     emit askUserForMnemonicChanged();
 }
 
+void Account::listRemoteFolder(QPromise<OCC::PlaceholderCreateInfo> *promise, const QString &remoteSyncRootPath, const QString &subPath, SyncJournalDb *journalForFolder)
+{
+    qCInfo(lcAccount()) << "ls col job requested for" << subPath;
+
+    if (!credentials()->ready()) {
+        qCWarning(lcAccount()) << "credentials are not ready" << subPath;
+        promise->finish();
+        return;
+    }
+
+    auto listFolderJob = new OCC::LsColJob{sharedFromThis(), subPath};
+
+    const auto props = LsColJob::defaultProperties(LsColJob::FolderType::ChildFolder, sharedFromThis());
+
+    listFolderJob->setProperties(props);
+
+    QObject::connect(listFolderJob, &OCC::LsColJob::networkError, this, [promise, subPath] (QNetworkReply *reply) {
+        if (reply) {
+            qCWarning(lcAccount()) << "ls col job" << subPath << "error" << reply->errorString();
+        }
+
+        qCWarning(lcAccount()) << "ls col job" << subPath << "error without a reply";
+        promise->finish();
+    });
+
+    QObject::connect(listFolderJob, &OCC::LsColJob::finishedWithError, this, [promise, subPath] (QNetworkReply *reply) {
+        if (reply) {
+            qCWarning(lcAccount()) << "ls col job" << subPath << "error" << reply->errorString();
+        }
+
+        qCWarning(lcAccount()) << "ls col job" << subPath << "error without a reply";
+        promise->finish();
+    });
+
+    QObject::connect(listFolderJob, &OCC::LsColJob::finishedWithoutError, this, [promise, subPath] () {
+        qCInfo(lcAccount()) << "ls col job" << subPath << "finished";
+        promise->finish();
+    });
+
+    listFolderJob->setProperty("ignoredFirst", false);
+    const auto baseRemotePath = Utility::trailingSlashPath(Utility::noLeadingSlashPath(remoteSyncRootPath));
+    auto syncRootPath = subPath;
+    if (subPath.startsWith(baseRemotePath)) {
+        syncRootPath = syncRootPath.mid(baseRemotePath.size());
+    }
+
+    QObject::connect(listFolderJob, &OCC::LsColJob::directoryListingIterated, this, [promise, remoteSyncRootPath, syncRootPath, journalForFolder, this](const QString &completeDavPath, const QMap<QString, QString> &properties) {
+        if (!sender()->property("ignoredFirst").toBool()) {
+            qCDebug(lcAccount()) << "skip first item";
+            sender()->setProperty("ignoredFirst", true);
+            return;
+        }
+
+        qCInfo(lcAccount()) << "ls col job" << syncRootPath << "new file" << completeDavPath << properties.count();
+
+        const auto slash = completeDavPath.lastIndexOf('/');
+        const auto itemFileName = completeDavPath.mid(slash + 1);
+        const auto absoluteItemPathName = syncRootPath.isEmpty() ? itemFileName : Utility::noTrailingSlashPath(syncRootPath) + '/' + itemFileName;
+
+        auto currentItemDbRecord = SyncJournalFileRecord{};
+        if (journalForFolder->getFileRecord(absoluteItemPathName, &currentItemDbRecord) && currentItemDbRecord.isValid()) {
+            qCWarning(lcAccount()) << "skip existing item" << absoluteItemPathName;
+            return;
+        }
+
+        auto newEntry = RemoteInfo{};
+
+        LsColJob::propertyMapToRemoteInfo(properties,
+                                          serverHasMountRootProperty() ? RemotePermissions::MountedPermissionAlgorithm::UseMountRootProperty : RemotePermissions::MountedPermissionAlgorithm::WildGuessMountedSubProperty,
+                                          newEntry);
+
+        promise->emplaceResult(itemFileName, itemFileName.toStdWString(), absoluteItemPathName, newEntry);
+    });
+
+    promise->start();
+    listFolderJob->start();
+    qCInfo(lcAccount()) << "ls col job started";
+}
+
 bool Account::serverHasValidSubscription() const
 {
     return _serverHasValidSubscription;
@@ -1162,38 +1285,6 @@ void Account::updateDesktopEnterpriseChannel()
     }
 }
 
-Account::AccountNetworkProxySetting Account::networkProxySetting() const
-{
-    return _networkProxySetting;
-}
-
-void Account::setNetworkProxySetting(const AccountNetworkProxySetting setting)
-{
-    if (setting == _networkProxySetting) {
-        return;
-    }
-
-    _networkProxySetting = setting;
-    if (setting == AccountNetworkProxySetting::AccountSpecificProxy) {
-        auto proxy = _networkAccessManager->proxy();
-        proxy.setType(proxyType());
-        proxy.setHostName(proxyHostName());
-        proxy.setPort(proxyPort());
-        proxy.setUser(proxyUser());
-        proxy.setPassword(proxyPassword());
-        _networkAccessManager->setProxy(proxy);
-    } else {
-        const auto proxy = QNetworkProxy::applicationProxy();
-        _networkAccessManager->setProxy(proxy);
-        setProxyType(proxy.type());
-        setProxyHostName(proxy.hostName());
-        setProxyPort(proxy.port());
-        setProxyUser(proxy.user());
-        setProxyPassword(proxy.password());
-    }
-    emit networkProxySettingChanged();
-}
-
 QNetworkProxy::ProxyType Account::proxyType() const
 {
     return _proxyType;
@@ -1207,11 +1298,13 @@ void Account::setProxyType(QNetworkProxy::ProxyType proxyType)
 
     _proxyType = proxyType;
 
-    if (networkProxySetting() == AccountNetworkProxySetting::AccountSpecificProxy) {
-        auto proxy = _networkAccessManager->proxy();
-        proxy.setType(proxyType);
-        _networkAccessManager->setProxy(proxy);
-    }
+    auto proxy = _networkAccessManager->proxy();
+    proxy.setType(proxyType);
+    proxy.setHostName(proxyHostName());
+    proxy.setPort(proxyPort());
+    proxy.setUser(proxyUser());
+    proxy.setPassword(proxyPassword());
+    _networkAccessManager->setProxy(proxy);
 
     emit proxyTypeChanged();
 }
@@ -1229,11 +1322,9 @@ void Account::setProxyHostName(const QString &hostName)
 
     _proxyHostName = hostName;
 
-    if (networkProxySetting() == AccountNetworkProxySetting::AccountSpecificProxy) {
-        auto proxy = _networkAccessManager->proxy();
-        proxy.setHostName(hostName);
-        _networkAccessManager->setProxy(proxy);
-    }
+    auto proxy = _networkAccessManager->proxy();
+    proxy.setHostName(hostName);
+    _networkAccessManager->setProxy(proxy);
 
     emit proxyHostNameChanged();
 }
@@ -1251,11 +1342,9 @@ void Account::setProxyPort(const int port)
 
     _proxyPort = port;
 
-    if (networkProxySetting() == AccountNetworkProxySetting::AccountSpecificProxy) {
-        auto proxy = _networkAccessManager->proxy();
-        proxy.setPort(port);
-        _networkAccessManager->setProxy(proxy);
-    }
+    auto proxy = _networkAccessManager->proxy();
+    proxy.setPort(port);
+    _networkAccessManager->setProxy(proxy);
 
     emit proxyPortChanged();
 }
@@ -1288,11 +1377,9 @@ void Account::setProxyUser(const QString &user)
 
     _proxyUser = user;
 
-    if (networkProxySetting() == AccountNetworkProxySetting::AccountSpecificProxy) {
-        auto proxy = _networkAccessManager->proxy();
-        proxy.setUser(user);
-        _networkAccessManager->setProxy(proxy);
-    }
+    auto proxy = _networkAccessManager->proxy();
+    proxy.setUser(user);
+    _networkAccessManager->setProxy(proxy);
 
     emit proxyUserChanged();
 }
@@ -1310,35 +1397,26 @@ void Account::setProxyPassword(const QString &password)
 
     _proxyPassword = password;
 
-    if (networkProxySetting() == AccountNetworkProxySetting::AccountSpecificProxy) {
-        auto proxy = _networkAccessManager->proxy();
-        proxy.setPassword(password);
-        _networkAccessManager->setProxy(proxy);
-    }
+    auto proxy = _networkAccessManager->proxy();
+    proxy.setPassword(password);
+    _networkAccessManager->setProxy(proxy);
 
     emit proxyPasswordChanged();
 }
 
-void Account::setProxySettings(const AccountNetworkProxySetting networkProxySetting,
-                               const QNetworkProxy::ProxyType proxyType,
+void Account::setProxySettings(const QNetworkProxy::ProxyType proxyType,
                                const QString &hostName,
                                const int port,
                                const bool needsAuth,
                                const QString &user,
                                const QString &password)
 {
-    if (networkProxySetting == AccountNetworkProxySetting::GlobalProxy) {
-        setNetworkProxySetting(networkProxySetting);
-        return;
-    }
-
     setProxyType(proxyType);
     setProxyHostName(hostName);
     setProxyPort(port);
     setProxyNeedsAuth(needsAuth);
     setProxyUser(user);
     setProxyPassword(password);
-    setNetworkProxySetting(networkProxySetting);
 }
 
 Account::AccountNetworkTransferLimitSetting Account::uploadLimitSetting() const
@@ -1352,7 +1430,14 @@ void Account::setUploadLimitSetting(const AccountNetworkTransferLimitSetting set
         return;
     }
 
-    _uploadLimitSetting = setting;
+    auto targetSetting = setting;
+
+    if (setting == AccountNetworkTransferLimitSetting::LegacyGlobalLimit) {
+        qCInfo(lcAccount) << "Upload limit setting was requested to be set to the legacy global limit, falling back to unlimited";
+        targetSetting = AccountNetworkTransferLimitSetting::NoLimit;
+    }
+
+    _uploadLimitSetting = targetSetting;
     emit uploadLimitSettingChanged();
 }
 
@@ -1366,8 +1451,15 @@ void Account::setDownloadLimitSetting(const AccountNetworkTransferLimitSetting s
     if (setting == _downloadLimitSetting) {
         return;
     }
-    
-    _downloadLimitSetting = setting;
+
+    auto targetSetting = setting;
+
+    if (setting == AccountNetworkTransferLimitSetting::LegacyGlobalLimit) {
+        qCInfo(lcAccount) << "Download limit setting was requested to be set to the legacy global limit, falling back to unlimited";
+        targetSetting = AccountNetworkTransferLimitSetting::NoLimit;
+    }
+
+    _downloadLimitSetting = targetSetting;
     emit downloadLimitSettingChanged();
 }
 
