@@ -1,15 +1,6 @@
 /*
- * Copyright (C) 2023 by Oleksandr Zolotov <alex@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "clientstatusreportingnetwork.h"
 
@@ -96,7 +87,7 @@ void ClientStatusReportingNetwork::sendReportToServer()
                 reportToServerSentSuccessfully();
                 return;
             }
-            qCDebug(lcClientStatusReportingNetwork) << "Received error when sending client report statusCode:" << statusCode << "codeFromJson:" << codeFromJson;
+            qCWarning(lcClientStatusReportingNetwork) << "Received error when sending client report statusCode:" << statusCode << "codeFromJson:" << codeFromJson;
         }
     });
     clientStatusReportingJob->start();
@@ -106,7 +97,7 @@ void ClientStatusReportingNetwork::reportToServerSentSuccessfully()
 {
     qCInfo(lcClientStatusReportingNetwork) << "Report sent successfully";
     if (!_database->deleteClientStatusReportingRecords()) {
-        qCDebug(lcClientStatusReportingNetwork) << "Could not delete records after sending the report";
+        qCWarning(lcClientStatusReportingNetwork) << "Could not delete records after sending the report";
     }
     _database->setLastSentReportTimestamp(QDateTime::currentDateTimeUtc().toMSecsSinceEpoch());
 }
@@ -133,7 +124,7 @@ QVariantMap ClientStatusReportingNetwork::prepareReport() const
         const auto categoryKey = classifyStatus(static_cast<ClientStatusReportingStatus>(record._status));
 
         if (categoryKey.isEmpty()) {
-            qCDebug(lcClientStatusReportingNetwork) << "Could not classify status:";
+            qCWarning(lcClientStatusReportingNetwork) << "Could not classify status:";
             continue;
         }
 
@@ -164,7 +155,7 @@ QByteArray ClientStatusReportingNetwork::classifyStatus(const ClientStatusReport
 {
     Q_ASSERT(static_cast<int>(status) >= 0 && static_cast<int>(status) < static_cast<int>(ClientStatusReportingStatus::Count));
     if (static_cast<int>(status) < 0 || static_cast<int>(status) >= static_cast<int>(ClientStatusReportingStatus::Count)) {
-        qCDebug(lcClientStatusReportingNetwork) << "Invalid status:" << static_cast<int>(status);
+        qCWarning(lcClientStatusReportingNetwork) << "Invalid status:" << static_cast<int>(status);
         return {};
     }
 
