@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -41,7 +33,7 @@
 #include <QStandardPaths>
 #include <QOperatingSystemVersion>
 
-#define DEFAULT_REMOTE_POLL_INTERVAL 30000 // default remote poll time in milliseconds
+#define DEFAULT_REMOTE_POLL_INTERVAL 30000
 #define DEFAULT_MAX_LOG_LINES 20000
 
 namespace {
@@ -54,7 +46,6 @@ static constexpr char fullLocalDiscoveryIntervalC[] = "fullLocalDiscoveryInterva
 static constexpr char notificationRefreshIntervalC[] = "notificationRefreshInterval";
 static constexpr char monoIconsC[] = "monoIcons";
 static constexpr char deleteFilesThresholdC[] = "deleteFilesThreshold";
-static constexpr char crashReporterC[] = "crashReporter";
 static constexpr char skipUpdateCheckC[] = "skipUpdateCheck";
 static constexpr char autoUpdateCheckC[] = "autoUpdateCheck";
 static constexpr char updateCheckIntervalC[] = "updateCheckInterval";
@@ -103,6 +94,8 @@ static const QString defaultUpdateChannelName = "stable";
 static const QStringList enterpriseUpdateChannelsList { QStringLiteral("stable"), QStringLiteral("enterprise") };
 static const QString defaultEnterpriseChannel = "enterprise";
 
+static constexpr char languageC[] = "language";
+
 static constexpr int deleteFilesThresholdDefaultValue = 100;
 }
 
@@ -223,6 +216,19 @@ void ConfigFile::setShowCallNotifications(bool show)
     settings.sync();
 }
 
+bool ConfigFile::showQuotaWarningNotifications() const
+{
+    const QSettings settings(configFile(), QSettings::IniFormat);
+    return settings.value(showQuotaWarningNotificationsC, true).toBool() && optionalServerNotifications();
+}
+
+void ConfigFile::setShowQuotaWarningNotifications(bool show)
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    settings.setValue(showQuotaWarningNotificationsC, show);
+    settings.sync();
+}
+
 bool ConfigFile::showInExplorerNavigationPane() const
 {
     const bool defaultValue =
@@ -435,7 +441,7 @@ QString ConfigFile::excludeFileFromSystem()
         }
     }
 #endif
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     // exec path is inside the bundle
     fi.setFile(QCoreApplication::applicationDirPath(),
         QLatin1String("../Resources/") + syncExclFile);
@@ -455,6 +461,16 @@ void OCC::ConfigFile::cleanUpdaterConfiguration()
     settings.sync();
 }
 
+void OCC::ConfigFile::cleanupGlobalNetworkConfiguration()
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    settings.remove(useUploadLimitC);
+    settings.remove(useDownloadLimitC);
+    settings.remove(uploadLimitC);
+    settings.remove(downloadLimitC);
+    settings.sync();
+}
+
 QString ConfigFile::backup(const QString &fileName) const
 {
     const QString baseFilePath = configPath() + fileName;
@@ -1075,7 +1091,7 @@ bool ConfigFile::monoIcons() const
 {
     QSettings settings(configFile(), QSettings::IniFormat);
     bool monoDefault = false; // On Mac we want bw by default
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     // OEM themes are not obliged to ship mono icons
     monoDefault = QByteArrayLiteral("Nextcloud") == QByteArrayLiteral(APPLICATION_NAME);
 #endif
@@ -1088,19 +1104,6 @@ void ConfigFile::setMonoIcons(bool useMonoIcons)
     settings.setValue(QLatin1String(monoIconsC), useMonoIcons);
 }
 
-bool ConfigFile::crashReporter() const
-{
-    QSettings settings(configFile(), QSettings::IniFormat);
-    const auto fallback = settings.value(QLatin1String(crashReporterC), true);
-    return getPolicySetting(QLatin1String(crashReporterC), fallback).toBool();
-}
-
-void ConfigFile::setCrashReporter(bool enabled)
-{
-    QSettings settings(configFile(), QSettings::IniFormat);
-    settings.setValue(QLatin1String(crashReporterC), enabled);
-}
-
 bool ConfigFile::automaticLogDir() const
 {
     QSettings settings(configFile(), QSettings::IniFormat);
@@ -1240,6 +1243,17 @@ void ConfigFile::setDesktopEnterpriseChannel(const QString &channel)
     settings.setValue(QLatin1String(desktopEnterpriseChannelName), channel);
 }
 
+QString ConfigFile::language() const
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    return settings.value(QLatin1String(languageC), QLatin1String("")).toString();
+}
+
+void ConfigFile::setLanguage(const QString& language)
+{
+    QSettings settings(configFile(), QSettings::IniFormat);
+    settings.setValue(QLatin1String(languageC), language);
+}
 
 Q_GLOBAL_STATIC(QString, g_configFileName)
 
@@ -1303,4 +1317,61 @@ void ConfigFile::setDiscoveredLegacyConfigPath(const QString &discoveredLegacyCo
     _discoveredLegacyConfigPath = discoveredLegacyConfigPath;
 }
 
+QString ConfigFile::fileProviderDomainUuidFromAccountId(const QString &accountId) const
+{
+    if (accountId.isEmpty()) {
+        return {};
+    }
+    return retrieveData(QStringLiteral("FileProviderDomainUuids"), accountId).toString();
+}
+
+void ConfigFile::setFileProviderDomainUuidForAccountId(const QString &accountId, const QString &domainUuid)
+{
+    if (accountId.isEmpty() || domainUuid.isEmpty()) {
+        return;
+    }
+
+    storeData(QStringLiteral("FileProviderDomainUuids"), accountId, domainUuid);
+    storeData(QStringLiteral("FileProviderAccountIds"), domainUuid, accountId);
+}
+
+QString ConfigFile::accountIdFromFileProviderDomainUuid(const QString &domainUuid) const
+{
+    if (domainUuid.isEmpty()) {
+        return {};
+    }
+
+    return retrieveData(QStringLiteral("FileProviderAccountIds"), domainUuid).toString();
+}
+
+void ConfigFile::removeFileProviderDomainUuidMapping(const QString &accountId)
+{
+    if (accountId.isEmpty()) {
+        return;
+    }
+
+    const QString domainUuid = fileProviderDomainUuidFromAccountId(accountId);
+
+    if (!domainUuid.isEmpty()) {
+        removeData(QStringLiteral("FileProviderAccountIds"), domainUuid);
+    }
+
+    removeData(QStringLiteral("FileProviderDomainUuids"), accountId);
+}
+
+void ConfigFile::removeFileProviderDomainMappingByDomainIdentifier(const QString domainIdentifier)
+{
+    if (domainIdentifier.isEmpty()) {
+        return;
+    }
+
+    removeData(QStringLiteral("FileProviderAccountIds"), domainIdentifier);
+
+    const QString accountIdentifier = accountIdFromFileProviderDomainUuid(domainIdentifier);
+
+    if (!accountIdentifier.isEmpty()) {
+        removeData(QStringLiteral("FileProviderDomainUuids"), accountIdentifier);
+    }
+}
+
 }
