@@ -1,24 +1,16 @@
 /*
- * Copyright (C) by Olivier Goffart <ogoffart@woboq.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "discoveryphase.h"
+
 #include "common/utility.h"
 #include "configfile.h"
 #include "discovery.h"
 #include "helpers.h"
 #include "progressdispatcher.h"
-
 #include "account.h"
 #include "clientsideencryptionjobs.h"
 #include "foldermetadata.h"
@@ -32,6 +24,7 @@
 #include <QLoggingCategory>
 #include <QUrl>
 #include <QFile>
+#include <QDir>
 #include <QFileInfo>
 #include <QTextCodec>
 #include <cstring>
@@ -82,7 +75,7 @@ void DiscoveryPhase::checkFolderSizeLimit(const QString &path, const std::functi
     connect(propfindJob, &PropfindJob::finishedWithError, this, [=] {
         return completionCallback(false);
     });
-    connect(propfindJob, &PropfindJob::result, this, [=](const QVariantMap &values) {
+    connect(propfindJob, &PropfindJob::result, this, [=, this](const QVariantMap &values) {
         const auto result = values.value(QLatin1String("size")).toLongLong();
         const auto limit = _syncOptions._newBigFolderSizeLimit;
         qCDebug(lcDiscovery) << "Folder size check complete for" << path << "result:" << result << "limit:" << limit;
@@ -117,6 +110,10 @@ void DiscoveryPhase::checkSelectiveSyncNewFolder(const QString &path,
         return callback(false);
     }
 
+    // if (_syncOptions._vfs->mode() == Vfs::WindowsCfApi) {
+    //     return callback(true);
+    // }
+
     checkFolderSizeLimit(path, [this, path, callback](const bool bigFolder) {
         if (bigFolder) {
             // we tell the UI there is a new folder
@@ -224,11 +221,38 @@ void DiscoveryPhase::enqueueDirectoryToDelete(const QString &path, ProcessDirect
     }
 }
 
+bool DiscoveryPhase::recursiveCheckForDeletedParents(const QString &itemPath) const
+{
+    const auto &allKeys = _deletedItem.keys();
+    qCDebug(lcDiscovery()) << allKeys.join(", ");
+
+    auto result = false;
+    const auto &pathElements = itemPath.split('/');
+    auto currentParentFolder = QString{};
+    for (const auto &onePathComponent : pathElements) {
+        if (!currentParentFolder.isEmpty()) {
+            currentParentFolder += '/';
+        }
+        currentParentFolder += onePathComponent;
+
+        qCDebug(lcDiscovery()) << "checks" << currentParentFolder << "for" << allKeys.join(", ");
+        if (_deletedItem.find(currentParentFolder) == _deletedItem.end()) {
+            continue;
+        }
+
+        qCDebug(lcDiscovery()) << "deleted parent found";
+        result = true;
+        break;
+    }
+
+    return result;
+}
+
 void DiscoveryPhase::markPermanentDeletionRequests()
 {
     // since we don't know in advance which files/directories need to be permanently deleted,
     // we have to look through all of them at the end of the run
-    for (const auto &originalPath : _permanentDeletionRequests) {
+    for (const auto &originalPath : std::as_const(_permanentDeletionRequests)) {
         const auto it = _deletedItem.find(originalPath);
         if (it == _deletedItem.end()) {
             qCWarning(lcDiscovery) << "didn't find an item for" << originalPath << "(yet)";
@@ -237,12 +261,12 @@ void DiscoveryPhase::markPermanentDeletionRequests()
 
         auto item = *it;
         if (!(item->_instruction == CSYNC_INSTRUCTION_REMOVE || item->_direction == SyncFileItem::Up)) {
-            qCWarning(lcDiscovery) << "will not request permanent deletion for" << originalPath << "as the instruction is not CSYNC_INSTRUCTION_REMOVE, or the direction is not Up";
+            qCInfo(lcDiscovery) << "will not request permanent deletion for" << originalPath << "as the instruction is not CSYNC_INSTRUCTION_REMOVE, or the direction is not Up";
             continue;
         }
 
-        qCInfo(lcDiscovery) << "requested permanent server-side deletion for" << originalPath;
-        item->_wantsPermanentDeletion = true;
+        qCDebug(lcDiscovery) << "requested permanent server-side deletion for" << originalPath;
+        item->_wantsSpecificActions = SyncFileItem::SynchronizationOptions::WantsPermanentDeletion;
     }
 }
 
@@ -365,7 +389,7 @@ void DiscoverySingleLocalDirectoryJob::run() {
         i.modtime = dirent->modtime;
         i.size = dirent->size;
         i.inode = dirent->inode;
-        i.isDirectory = dirent->type == ItemTypeDirectory;
+        i.isDirectory = dirent->type == ItemTypeDirectory || dirent->type == ItemTypeVirtualDirectory;
         i.isHidden = dirent->is_hidden;
         i.isSymLink = dirent->type == ItemTypeSoftLink;
         i.isVirtualFile = dirent->type == ItemTypeVirtualFile || dirent->type == ItemTypeVirtualFileDownload;
@@ -396,11 +420,13 @@ DiscoverySingleDirectoryJob::DiscoverySingleDirectoryJob(const AccountPtr &accou
                                                          const QString &path,
                                                          const QString &remoteRootFolderPath,
                                                          const QSet<QString> &topLevelE2eeFolderPaths,
+                                                         SyncFileItem::EncryptionStatus parentEncryptionStatus,
                                                          QObject *parent)
     : QObject(parent)
     , _subPath(remoteRootFolderPath + path)
     , _remoteRootFolderPath(remoteRootFolderPath)
     , _account(account)
+    , _encryptionStatusCurrent{parentEncryptionStatus}
     , _topLevelE2eeFolderPaths(topLevelE2eeFolderPaths)
 {
     Q_ASSERT(!_remoteRootFolderPath.isEmpty());
@@ -411,39 +437,8 @@ void DiscoverySingleDirectoryJob::start()
     // Start the actual HTTP job
     auto *lsColJob = new LsColJob(_account, _subPath);
 
-    QList<QByteArray> props;
-    props << "resourcetype"
-          << "getlastmodified"
-          << "getcontentlength"
-          << "getetag"
-          << "http://owncloud.org/ns:size"
-          << "http://owncloud.org/ns:id"
-          << "http://owncloud.org/ns:fileid"
-          << "http://owncloud.org/ns:downloadURL"
-          << "http://owncloud.org/ns:dDC"
-          << "http://owncloud.org/ns:permissions"
-          << "http://owncloud.org/ns:checksums"
-          << "http://nextcloud.org/ns:is-encrypted"
-          << "http://nextcloud.org/ns:metadata-files-live-photo";
-
-    if (_isRootPath)
-        props << "http://owncloud.org/ns:data-fingerprint";
-    if (_account->serverVersionInt() >= Account::makeServerVersion(10, 0, 0)) {
-        // Server older than 10.0 have performances issue if we ask for the share-types on every PROPFIND
-        props << "http://owncloud.org/ns:share-types";
-    }
-    if (_account->capabilities().filesLockAvailable()) {
-        props << "http://nextcloud.org/ns:lock"
-              << "http://nextcloud.org/ns:lock-owner-displayname"
-              << "http://nextcloud.org/ns:lock-owner"
-              << "http://nextcloud.org/ns:lock-owner-type"
-              << "http://nextcloud.org/ns:lock-owner-editor"
-              << "http://nextcloud.org/ns:lock-time"
-              << "http://nextcloud.org/ns:lock-timeout"
-              << "http://nextcloud.org/ns:lock-token";
-    }
-    props << "http://nextcloud.org/ns:is-mount-root";
-
+    const auto props = LsColJob::defaultProperties(_isRootPath ? LsColJob::FolderType::RootFolder : LsColJob::FolderType::ChildFolder,
+                                                   _account);
     lsColJob->setProperties(props);
 
     QObject::connect(lsColJob, &LsColJob::directoryListingIterated,
@@ -482,121 +477,13 @@ SyncFileItem::EncryptionStatus DiscoverySingleDirectoryJob::requiredEncryptionSt
     return _encryptionStatusRequired;
 }
 
-QByteArray DiscoverySingleDirectoryJob::certificateSha256Fingerprint() const
-{
-    return _e2eCertificateFingerprint;
-}
-
-static void propertyMapToRemoteInfo(const QMap<QString, QString> &map, RemotePermissions::MountedPermissionAlgorithm algorithm, RemoteInfo &result)
-{
-    for (auto it = map.constBegin(); it != map.constEnd(); ++it) {
-        QString property = it.key();
-        QString value = it.value();
-        if (property == QLatin1String("resourcetype")) {
-            result.isDirectory = value.contains(QLatin1String("collection"));
-        } else if (property == QLatin1String("getlastmodified")) {
-            value.replace("GMT", "+0000");
-            const auto date = QDateTime::fromString(value, Qt::RFC2822Date);
-            Q_ASSERT(date.isValid());
-            result.modtime = 0;
-            if (date.toSecsSinceEpoch() > 0) {
-                result.modtime = date.toSecsSinceEpoch();
-            }
-        } else if (property == QLatin1String("getcontentlength")) {
-            // See #4573, sometimes negative size values are returned
-            bool ok = false;
-            qlonglong ll = value.toLongLong(&ok);
-            if (ok && ll >= 0) {
-                result.size = ll;
-            } else {
-                result.size = 0;
-            }
-        } else if (property == "getetag") {
-            result.etag = Utility::normalizeEtag(value.toUtf8());
-        } else if (property == "id") {
-            result.fileId = value.toUtf8();
-        } else if (property == "downloadURL") {
-            result.directDownloadUrl = value;
-        } else if (property == "dDC") {
-            result.directDownloadCookies = value;
-        } else if (property == "permissions") {
-            result.remotePerm = RemotePermissions::fromServerString(value, algorithm, map);
-        } else if (property == "checksums") {
-            result.checksumHeader = findBestChecksum(value.toUtf8());
-        } else if (property == "share-types" && !value.isEmpty()) {
-            // Since QMap is sorted, "share-types" is always after "permissions".
-            if (result.remotePerm.isNull()) {
-                qWarning() << "Server returned a share type, but no permissions?";
-            } else {
-                // S means shared with me.
-                // But for our purpose, we want to know if the file is shared. It does not matter
-                // if we are the owner or not.
-                // Piggy back on the permission field
-                result.remotePerm.setPermission(RemotePermissions::IsShared);
-                result.sharedByMe = true;
-            }
-        } else if (property == "is-encrypted" && value == QStringLiteral("1")) {
-            result._isE2eEncrypted = true;
-        } else if (property == "lock") {
-            result.locked = (value == QStringLiteral("1") ? SyncFileItem::LockStatus::LockedItem : SyncFileItem::LockStatus::UnlockedItem);
-        }
-        if (property == "lock-owner-displayname") {
-            result.lockOwnerDisplayName = value;
-        }
-        if (property == "lock-owner") {
-            result.lockOwnerId = value;
-        }
-        if (property == "lock-owner-type") {
-            auto ok = false;
-            const auto intConvertedValue = value.toULongLong(&ok);
-            if (ok) {
-                result.lockOwnerType = static_cast<SyncFileItem::LockOwnerType>(intConvertedValue);
-            } else {
-                result.lockOwnerType = SyncFileItem::LockOwnerType::UserLock;
-            }
-        }
-        if (property == "lock-owner-editor") {
-            result.lockEditorApp = value;
-        }
-        if (property == "lock-time") {
-            auto ok = false;
-            const auto intConvertedValue = value.toULongLong(&ok);
-            if (ok) {
-                result.lockTime = intConvertedValue;
-            } else {
-                result.lockTime = 0;
-            }
-        }
-        if (property == "lock-timeout") {
-            auto ok = false;
-            const auto intConvertedValue = value.toULongLong(&ok);
-            if (ok) {
-                result.lockTimeout = intConvertedValue;
-            } else {
-                result.lockTimeout = 0;
-            }
-        }
-        if (property == "lock-token") {
-            result.lockToken = value;
-        }
-        if (property == "metadata-files-live-photo") {
-            result.livePhotoFile = value;
-            result.isLivePhoto = true;
-        }
-    }
-
-    if (result.isDirectory && map.contains("size")) {
-        result.sizeOfFolder = map.value("size").toInt();
-    }
-}
-
 void DiscoverySingleDirectoryJob::directoryListingIteratedSlot(const QString &file, const QMap<QString, QString> &map)
 {
     if (!_ignoredFirst) {
         // The first entry is for the folder itself, we should process it differently.
         _ignoredFirst = true;
         if (map.contains("permissions")) {
-            auto perm = RemotePermissions::fromServerString(map.value("permissions"),
+            const auto perm = RemotePermissions::fromServerString(map.value("permissions"),
                                                             _account->serverHasMountRootProperty() ? RemotePermissions::MountedPermissionAlgorithm::UseMountRootProperty : RemotePermissions::MountedPermissionAlgorithm::WildGuessMountedSubProperty,
                                                             map);
             emit firstDirectoryPermissions(perm);
@@ -616,20 +503,37 @@ void DiscoverySingleDirectoryJob::directoryListingIteratedSlot(const QString &fi
             _fileId = map.value("id").toUtf8();
         }
         if (map.contains("is-encrypted") && map.value("is-encrypted") == QStringLiteral("1")) {
-            _encryptionStatusCurrent = SyncFileItem::EncryptionStatus::Encrypted;
+            _encryptionStatusCurrent = SyncFileItem::EncryptionStatus::EncryptedMigratedV2_0;
             Q_ASSERT(!_fileId.isEmpty());
         }
         if (map.contains("size")) {
             _size = map.value("size").toInt();
         }
+
+        // all folders will contain both
+        if (map.contains(FolderQuota::usedBytesC) && map.contains(FolderQuota::availableBytesC)) {          
+            // The server can respond with e.g. "2.58440798353E+12" for the quota
+            // therefore: parse the string as a double and cast it to i64
+            auto ok = false;
+            auto quotaValue = static_cast<int64_t>(map.value(FolderQuota::usedBytesC).toDouble(&ok));
+            _folderQuota.bytesUsed = ok ? quotaValue : -1;
+            quotaValue = static_cast<int64_t>(map.value(FolderQuota::availableBytesC).toDouble(&ok));
+            _folderQuota.bytesAvailable = ok ? quotaValue : -1;
+
+            qCDebug(lcDiscovery) << "Setting quota for" << file
+                                 << "bytesUsed:" << _folderQuota.bytesUsed
+                                 << "bytesAvailable:" << _folderQuota.bytesAvailable
+                                 << "ok:" << ok;
+            emit setfolderQuota(_folderQuota);
+        }
     } else {
         RemoteInfo result;
         int slash = file.lastIndexOf('/');
         result.name = file.mid(slash + 1);
         result.size = -1;
-        propertyMapToRemoteInfo(map,
-                                _account->serverHasMountRootProperty() ? RemotePermissions::MountedPermissionAlgorithm::UseMountRootProperty : RemotePermissions::MountedPermissionAlgorithm::WildGuessMountedSubProperty,
-                                result);
+        LsColJob::propertyMapToRemoteInfo(map,
+                                          _account->serverHasMountRootProperty() ? RemotePermissions::MountedPermissionAlgorithm::UseMountRootProperty : RemotePermissions::MountedPermissionAlgorithm::WildGuessMountedSubProperty,
+                                          result);
         if (result.isDirectory)
             result.size = 0;
 
@@ -660,36 +564,34 @@ void DiscoverySingleDirectoryJob::lsJobFinishedWithoutErrorSlot()
         emit etag(_firstEtag, QDateTime::fromString(QString::fromUtf8(_lsColJob->responseTimestamp()), Qt::RFC2822Date));
         fetchE2eMetadata();
         return;
-    } else if (isE2eEncrypted() && !_account->capabilities().clientSideEncryptionAvailable()) {
-        emit etag(_firstEtag, QDateTime::fromString(QString::fromUtf8(_lsColJob->responseTimestamp()), Qt::RFC2822Date));
-        emit finished(_results);
     }
     emit etag(_firstEtag, QDateTime::fromString(QString::fromUtf8(_lsColJob->responseTimestamp()), Qt::RFC2822Date));
     emit finished(_results);
     deleteLater();
 }
 
-void DiscoverySingleDirectoryJob::lsJobFinishedWithErrorSlot(QNetworkReply *r)
+void DiscoverySingleDirectoryJob::lsJobFinishedWithErrorSlot(QNetworkReply *reply)
 {
-    const auto contentType = r->header(QNetworkRequest::ContentTypeHeader).toString();
+    const auto contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     const auto invalidContentType = !contentType.contains("application/xml; charset=utf-8") &&
                                     !contentType.contains("application/xml; charset=\"utf-8\"") &&
                                     !contentType.contains("text/xml; charset=utf-8") &&
                                     !contentType.contains("text/xml; charset=\"utf-8\"");
-    const auto httpCode = r->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-    auto msg = r->errorString();
+    const auto httpCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+    auto errorString = _lsColJob->errorString();
 
-    qCWarning(lcDiscovery) << "LSCOL job error" << r->errorString() << httpCode << r->error();
+    qCWarning(lcDiscovery) << "LSCOL job error" << reply->errorString() << httpCode << reply->error();
 
-    if (r->error() == QNetworkReply::NoError && invalidContentType) {
-        msg = tr("Server error: PROPFIND reply is not XML formatted!");
+    if (reply->error() == QNetworkReply::NoError && invalidContentType) {
+        errorString = tr("The server returned an unexpected response that couldn’t be read. Please reach out to your server administrator.”");
+        qCWarning(lcDiscovery) << "Server error: PROPFIND reply is not XML formatted!";
     }
 
-    if (r->error() == QNetworkReply::ContentAccessDenied) {
+    if (reply->error() == QNetworkReply::ContentAccessDenied) {
         emit _account->termsOfServiceNeedToBeChecked();
     }
 
-    emit finished(HttpError{ httpCode, msg });
+    emit finished(HttpError{ httpCode, errorString });
     deleteLater();
 }
 
@@ -721,7 +623,7 @@ void DiscoverySingleDirectoryJob::metadataReceived(const QJsonDocument &json, in
     // hence, we need to find its path and pass to any subfolder's metadata, so it will fetch the top level metadata when needed
     // see https://github.com/nextcloud/end_to_end_encryption_rfc/blob/v2.1/RFC.md
     auto topLevelFolderPath = QStringLiteral("/");
-    for (const QString &topLevelPath : _topLevelE2eeFolderPaths) {
+    for (const QString &topLevelPath : std::as_const(_topLevelE2eeFolderPaths)) {
         if (_subPath == topLevelPath) {
             topLevelFolderPath = QStringLiteral("/");
             break;
@@ -755,10 +657,12 @@ void DiscoverySingleDirectoryJob::metadataReceived(const QJsonDocument &json, in
         }
         _isFileDropDetected = e2EeFolderMetadata->isFileDropPresent();
         _encryptedMetadataNeedUpdate = e2EeFolderMetadata->encryptedMetadataNeedUpdate();
-        _e2eCertificateFingerprint = e2EeFolderMetadata->certificateSha256Fingerprint();
         _encryptionStatusRequired = EncryptionStatusEnums::fromEndToEndEncryptionApiVersion(_account->capabilities().clientSideEncryptionVersion());
         _encryptionStatusCurrent = e2EeFolderMetadata->existingMetadataEncryptionStatus();
 
+        Q_ASSERT(_encryptionStatusCurrent != SyncFileItem::EncryptionStatus::Encrypted);
+        Q_ASSERT(_encryptionStatusCurrent != SyncFileItem::EncryptionStatus::NotEncrypted);
+
         const auto encryptedFiles = e2EeFolderMetadata->files();
 
         const auto findEncryptedFile = [=](const QString &name) {
@@ -772,7 +676,7 @@ void DiscoverySingleDirectoryJob::metadataReceived(const QJsonDocument &json, in
             }
         };
 
-        std::transform(std::cbegin(_results), std::cend(_results), std::begin(_results), [=](const RemoteInfo &info) {
+        std::transform(std::cbegin(_results), std::cend(_results), std::begin(_results), [=, this](const RemoteInfo &info) {
             auto result = info;
             const auto encryptedFileInfo = findEncryptedFile(result.name);
             if (encryptedFileInfo) {
