@@ -1,32 +1,28 @@
 /*
- * Copyright (C) by Olivier Goffart <ogoffart@woboq.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
+#include "networkjobs.h"
+#include "syncoptions.h"
+#include "syncfileitem.h"
+
+#include "common/folderquota.h"
+#include "common/remoteinfo.h"
+
 #include <QObject>
 #include <QElapsedTimer>
 #include <QStringList>
 #include <csync.h>
 #include <QMap>
 #include <QSet>
-#include "networkjobs.h"
 #include <QMutex>
 #include <QWaitCondition>
 #include <QRunnable>
 #include <deque>
-#include "syncoptions.h"
-#include "syncfileitem.h"
 
 class ExcludedFiles;
 
@@ -53,46 +49,6 @@ class ProcessDirectoryJob;
 
 enum class ErrorCategory;
 
-/**
- * Represent all the meta-data about a file in the server
- */
-struct RemoteInfo
-{
-    /** FileName of the entry (this does not contains any directory or path, just the plain name */
-    QString name;
-    QByteArray etag;
-    QByteArray fileId;
-    QByteArray checksumHeader;
-    OCC::RemotePermissions remotePerm;
-    time_t modtime = 0;
-    int64_t size = 0;
-    int64_t sizeOfFolder = 0;
-    bool isDirectory = false;
-    bool _isE2eEncrypted = false;
-    bool isFileDropDetected = false;
-    QString e2eMangledName;
-    QByteArray e2eCertificateFingerprint;
-    bool sharedByMe = false;
-
-    [[nodiscard]] bool isValid() const { return !name.isNull(); }
-    [[nodiscard]] bool isE2eEncrypted() const { return _isE2eEncrypted; }
-
-    QString directDownloadUrl;
-    QString directDownloadCookies;
-
-    SyncFileItem::LockStatus locked = SyncFileItem::LockStatus::UnlockedItem;
-    QString lockOwnerDisplayName;
-    QString lockOwnerId;
-    SyncFileItem::LockOwnerType lockOwnerType = SyncFileItem::LockOwnerType::UserLock;
-    QString lockEditorApp;
-    qint64 lockTime = 0;
-    qint64 lockTimeout = 0;
-    QString lockToken;
-
-    bool isLivePhoto = false;
-    QString livePhotoFile;
-};
-
 struct LocalInfo
 {
     /** FileName of the entry (this does not contains any directory or path, just the plain name */
@@ -156,6 +112,7 @@ public:
         sounds to me like it would be much more efficient to just have the e2ee parent folder that we are
         inside*/
                                          const QSet<QString> &topLevelE2eeFolderPaths,
+                                         SyncFileItem::EncryptionStatus parentEncryptionStatus,
                                          QObject *parent = nullptr);
     // Specify that this is the root and we need to check the data-fingerprint
     void setIsRootPath() { _isRootPath = true; }
@@ -163,7 +120,6 @@ public:
     void abort();
     [[nodiscard]] bool isFileDropDetected() const;
     [[nodiscard]] bool encryptedMetadataNeedUpdate() const;
-    [[nodiscard]] QByteArray certificateSha256Fingerprint() const;
     [[nodiscard]] SyncFileItem::EncryptionStatus currentEncryptionStatus() const;
     [[nodiscard]] SyncFileItem::EncryptionStatus requiredEncryptionStatus() const;
 
@@ -172,11 +128,12 @@ signals:
     void firstDirectoryPermissions(OCC::RemotePermissions);
     void etag(const QByteArray &, const QDateTime &time);
     void finished(const OCC::HttpResult<QVector<OCC::RemoteInfo>> &result);
+    void setfolderQuota(const FolderQuota &folderQuota);
 
 private slots:
     void directoryListingIteratedSlot(const QString &, const QMap<QString, QString> &);
     void lsJobFinishedWithoutErrorSlot();
-    void lsJobFinishedWithErrorSlot(QNetworkReply *);
+    void lsJobFinishedWithErrorSlot(QNetworkReply *reply);
     void fetchE2eMetadata();
     void metadataReceived(const QJsonDocument &json, int statusCode);
     void metadataError(const QByteArray& fileId, int httpReturnCode);
@@ -204,7 +161,6 @@ private:
     bool _isFileDropDetected = false;
     bool _encryptedMetadataNeedUpdate = false;
     SyncFileItem::EncryptionStatus _encryptionStatusRequired = SyncFileItem::EncryptionStatus::NotEncrypted;
-    QByteArray _e2eCertificateFingerprint;
 
     // If set, the discovery will finish with an error
     int64_t _size = 0;
@@ -216,6 +172,7 @@ private:
 
 public:
     QByteArray _dataFingerprint;
+    FolderQuota _folderQuota;
 };
 
 class DiscoveryPhase : public QObject
@@ -315,6 +272,8 @@ class DiscoveryPhase : public QObject
 
     void enqueueDirectoryToDelete(const QString &path, ProcessDirectoryJob* const directoryJob);
 
+    bool recursiveCheckForDeletedParents(const QString &itemPath) const;
+
     /// contains files/folder names that are requested to be deleted permanently
     QSet<QString> _permanentDeletionRequests;
 
