@@ -1,16 +1,7 @@
 /*
- * Copyright (C) by Olivier Goffart <ogoffart@owncloud.com>
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "account.h"
@@ -66,6 +57,23 @@ bool PropagateLocalRemove::removeRecursively(const QString &path)
                                                        [&deleted](const QString &path, bool isDir) {
                                                            // by prepending, a folder deletion may be followed by content deletions
                                                            deleted.prepend(qMakePair(path, isDir));
+                                                       },
+                                                       nullptr,
+                                                       nullptr,
+                                                       [this] (const QString &itemPath, QString *removeError) -> bool {
+                                                           auto result = false;
+
+                                                           qCInfo(lcPropagateLocalRemove()) << itemPath << _deleteToClientTrashBin;
+                                                           if (_deleteToClientTrashBin.contains(itemPath)) {
+                                                               result = FileSystem::moveToTrash(itemPath, removeError);
+                                                               if (!result) {
+                                                                   result = FileSystem::remove(itemPath, removeError);
+                                                               }
+                                                           } else {
+                                                               result = FileSystem::remove(itemPath, removeError);
+                                                           }
+
+                                                           return result;
                                                        });
 
     if (!success) {
@@ -93,7 +101,7 @@ void PropagateLocalRemove::start()
     qCInfo(lcPropagateLocalRemove) << "Start propagate local remove job";
     qCInfo(lcPermanentLog) << "delete" << _item->_file << _item->_discoveryResult;
 
-    _moveToTrash = propagator()->syncOptions()._moveFilesToTrash;
+    _moveToTrash = propagator()->syncOptions()._moveFilesToTrash || _item->_wantsSpecificActions == SyncFileItem::SynchronizationOptions::MoveToClientTrashBin;
 
     if (propagator()->_abortRequested)
         return;
