@@ -1,16 +1,7 @@
 /*
- * Copyright (C) by Olivier Goffart <ogoffart@owncloud.com>
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
@@ -40,11 +31,19 @@ public:
         : PropagateItemJob(propagator, item)
     {
     }
+
+    void willDeleteItemToClientTrashBin(const QString &itemFilePath)
+    {
+        _deleteToClientTrashBin.insert(itemFilePath);
+    }
+
     void start() override;
 
 private:
     bool removeRecursively(const QString &path);
-    QString _error;
+
+    QSet<QString> _deleteToClientTrashBin;
+
     bool _moveToTrash = false;
 };
 
