@@ -1,16 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- * Copyright (C) by Jocelyn Turcotte <jturcotte@woboq.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "syncfilestatustracker.h"
@@ -30,7 +21,7 @@ static int pathCompare( const QString& lhs, const QString& rhs )
 {
     // Should match Utility::fsCasePreserving, we want don't want to pay for the runtime check on every comparison.
     return lhs.compare(rhs,
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
         Qt::CaseInsensitive
 #else
         Qt::CaseSensitive
@@ -41,7 +32,7 @@ static int pathCompare( const QString& lhs, const QString& rhs )
 static bool pathStartsWith( const QString& lhs, const QString& rhs )
 {
     return lhs.startsWith(rhs,
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
         Qt::CaseInsensitive
 #else
         Qt::CaseSensitive
@@ -237,9 +228,9 @@ void SyncFileStatusTracker::slotAboutToPropagate(SyncFileItemVector &items)
 
     for (const auto &item : std::as_const(items)) {
         if (item->_instruction == CSyncEnums::CSYNC_INSTRUCTION_RENAME) {
-            qCInfo(lcStatusTracker) << "Investigating" << item->destination() << item->_status << item->_instruction << item->_direction << item->_file << item->_originalFile << item->_renameTarget;
+            qCInfo(lcStatusTracker) << "Investigating" << item->destination() << item->_status << item->_instruction << item->_direction << item->_type << item->_file << item->_originalFile << item->_renameTarget;
         } else {
-            qCInfo(lcStatusTracker) << "Investigating" << item->destination() << item->_status << item->_instruction << item->_direction;
+            qCInfo(lcStatusTracker) << "Investigating" << item->destination() << item->_status << item->_instruction << item->_direction << item->_type;
         }
         _dirtyPaths.remove(item->destination());
 
