@@ -1,19 +1,10 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2012 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "theme.h"
-#include "config.h"
 #include "common/utility.h"
 #include "version.h"
 #include "configfile.h"
@@ -172,6 +163,11 @@ QUrl Theme::statusAwayImageSource() const
     return imagePathToUrl(themeImagePath("user-status-away", 16));
 }
 
+QUrl Theme::statusBusyImageSource() const
+{
+    return imagePathToUrl(themeImagePath("user-status-busy", 16));
+}
+
 QUrl Theme::statusInvisibleImageSource() const
 {
     return imagePathToUrl(themeImagePath("user-status-invisible", 64));
@@ -207,6 +203,40 @@ QUrl Theme::folderOffline() const
     return imagePathToUrl(themeImagePath("state-offline"));
 }
 
+/*
+ * neutral icons for in-app status
+ */
+
+QUrl Theme::offline() const
+{
+    return imagePathToUrl(themeImagePath("offline"));
+}
+
+QUrl Theme::ok() const
+{
+    return imagePathToUrl(themeImagePath("ok"));
+}
+
+QUrl Theme::error() const
+{
+    return imagePathToUrl(themeImagePath("error"));
+}
+
+QUrl Theme::sync() const
+{
+    return imagePathToUrl(themeImagePath("sync"));
+}
+
+QUrl Theme::pause() const
+{
+    return imagePathToUrl(themeImagePath("pause"));
+}
+
+QUrl Theme::warning() const
+{
+    return imagePathToUrl(themeImagePath("warning"));
+}
+
 QString Theme::version() const
 {
     return MIRALL_VERSION_STRING;
@@ -284,7 +314,7 @@ QIcon Theme::themeIcon(const QString &name, bool sysTray) const
         }
     }
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     // This defines the icon as a template and enables automatic macOS color handling
     // See https://bugreports.qt.io/browse/QTBUG-42109
     cached.setIsMask(_mono && sysTray);
@@ -513,14 +543,7 @@ bool Theme::forbidBadSSL() const
 #endif
 }
 
-bool Theme::doNotUseProxy() const
-{
-#ifdef DO_NOT_USE_PROXY
-    return true;
-#else
-    return false;
-#endif
-}
+
 
 QString Theme::forceConfigAuthType() const
 {
@@ -695,7 +718,6 @@ QIcon Theme::syncStateIcon(SyncResult::Status status, bool sysTray) const
         break;
     case SyncResult::Error:
     case SyncResult::SetupError:
-    // FIXME: Use state-problem once we have an icon.
     default:
         statusIcon = QLatin1String("state-error");
     }
@@ -703,9 +725,42 @@ QIcon Theme::syncStateIcon(SyncResult::Status status, bool sysTray) const
     return themeIcon(statusIcon, sysTray);
 }
 
-QIcon Theme::folderDisabledIcon() const
+// Neutral icons for the classic sync folder list
+
+QIcon Theme::folderStateIcon(SyncResult::Status status) const
 {
-    return themeIcon(QLatin1String("state-pause"));
+    // FIXME: Mind the size!
+    QString statusIcon;
+
+    switch (status) {
+    case SyncResult::Undefined:
+        // this can happen if no sync connections are configured.
+        statusIcon = QLatin1String("warning");
+        break;
+    case SyncResult::NotYetStarted:
+    case SyncResult::SyncRunning:
+        statusIcon = QLatin1String("sync");
+        break;
+    case SyncResult::SyncAbortRequested:
+    case SyncResult::Paused:
+        statusIcon = QLatin1String("pause");
+        break;
+    case SyncResult::SyncPrepare:
+    case SyncResult::Success:
+        statusIcon = QLatin1String("ok");
+        break;
+    case SyncResult::Problem:
+        statusIcon = QLatin1String("warning");
+        break;
+    case SyncResult::SetupError:
+        statusIcon = QLatin1String("offline");
+        break;
+    case SyncResult::Error:
+    default:
+        statusIcon = QLatin1String("error");
+    }
+
+    return themeIcon(statusIcon, false);
 }
 
 QIcon Theme::folderOfflineIcon(bool sysTray) const
