@@ -1,25 +1,20 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2012 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef _THEME_H
 #define _THEME_H
 
+#include "config.h"
+
+#include "syncresult.h"
+
 #include <QIcon>
 #include <QObject>
 #include <QPalette>
 #include <QGuiApplication>
-#include "syncresult.h"
 
 class QString;
 class QObject;
@@ -46,9 +41,9 @@ class OWNCLOUDSYNC_EXPORT Theme : public QObject
     Q_PROPERTY(QUrl statusOnlineImageSource READ statusOnlineImageSource CONSTANT)
     Q_PROPERTY(QUrl statusDoNotDisturbImageSource READ statusDoNotDisturbImageSource CONSTANT)
     Q_PROPERTY(QUrl statusAwayImageSource READ statusAwayImageSource CONSTANT)
+    Q_PROPERTY(QUrl statusBusyImageSource READ statusBusyImageSource CONSTANT)
     Q_PROPERTY(QUrl statusInvisibleImageSource READ statusInvisibleImageSource CONSTANT)
 #ifndef TOKEN_AUTH_ONLY
-    Q_PROPERTY(QIcon folderDisabledIcon READ folderDisabledIcon CONSTANT)
     Q_PROPERTY(QIcon folderOfflineIcon READ folderOfflineIcon CONSTANT)
     Q_PROPERTY(QIcon applicationIcon READ applicationIcon CONSTANT)
 #endif
@@ -153,6 +148,12 @@ public:
      */
     [[nodiscard]] QUrl statusAwayImageSource() const;
     
+    /**
+     * @brief Returns full path to a busy user status icon
+     * @return QUrl full path to an icon
+     */
+    [[nodiscard]] QUrl statusBusyImageSource() const;
+    
     /**
      * @brief Returns full path to an invisible user status icon
      * @return QUrl full path to an icon
@@ -171,6 +172,22 @@ public:
 
     [[nodiscard]] QUrl folderOffline() const;
 
+    /**
+     * @brief nneutral icons for in-app status
+     * @return QUrl full path to an icon
+     */
+    [[nodiscard]] QUrl offline() const;
+
+    [[nodiscard]] QUrl ok() const;
+
+    [[nodiscard]] QUrl error() const;
+
+    [[nodiscard]] QUrl sync() const;
+
+    [[nodiscard]] QUrl pause() const;
+
+    [[nodiscard]] QUrl warning() const;
+
     /**
      * @brief configFileName
      * @return the name of the config file.
@@ -188,8 +205,7 @@ public:
       * get an sync state icon
       */
     [[nodiscard]] QIcon syncStateIcon(SyncResult::Status, bool sysTray = false) const;
-
-    [[nodiscard]] QIcon folderDisabledIcon() const;
+    [[nodiscard]] QIcon folderStateIcon(SyncResult::Status) const;
     [[nodiscard]] QIcon folderOfflineIcon(bool sysTray = false) const;
     [[nodiscard]] QIcon applicationIcon() const;
 #endif
@@ -283,7 +299,10 @@ public:
      *
      * When true, the app always connects to the server directly
      */
-    [[nodiscard]] bool doNotUseProxy() const;
+    [[nodiscard]] constexpr static bool doNotUseProxy()
+    {
+        return DO_NOT_USE_PROXY;
+    }
 
     /**
      * This is only useful when previous version had a different overrideServerUrl
