@@ -1,15 +1,6 @@
 /*
- * Copyright (C) by Kevin Ottens <kevin.ottens@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "hydrationjob.h"
@@ -33,6 +24,8 @@ OCC::HydrationJob::HydrationJob(QObject *parent)
 {
 }
 
+OCC::HydrationJob::~HydrationJob() = default;
+
 OCC::AccountPtr OCC::HydrationJob::account() const
 {
     return _account;
@@ -203,7 +196,7 @@ void OCC::HydrationJob::emitFinished(Status status)
     }
 
     if (status == Success) {
-        connect(_transferDataSocket, &QLocalSocket::disconnected, this, [=] {
+        connect(_transferDataSocket, &QLocalSocket::disconnected, this, [=, this] {
             _transferDataSocket->close();
             emit finished(this);
         });
