@@ -1,15 +1,6 @@
 /*
- * Copyright (C) by Kevin Ottens <kevin.ottens@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "vfs_cfapi.h"
@@ -63,7 +54,7 @@ bool registerShellExtension()
         return false;
     }
 
-    for (const auto extension : listExtensions) {
+    for (const auto &extension : listExtensions) {
         const QString clsidPath = QString() % clsIdRegKey % extension.second;
         const QString clsidServerPath = clsidPath % R"(\InprocServer32)";
 
@@ -96,7 +87,7 @@ void unregisterShellExtensions()
         CFAPI_SHELLEXT_THUMBNAIL_HANDLER_CLASS_ID_REG
     };
 
-    for (const auto extension : listExtensions) {
+    for (const auto &extension : listExtensions) {
         const QString clsidPath = QString() % clsIdRegKey % extension;
         if (OCC::Utility::registryKeyExists(rootKey, clsidPath)) {
             OCC::Utility::registryDeleteKeyTree(rootKey, clsidPath);
@@ -112,7 +103,7 @@ class VfsCfApiPrivate
 {
 public:
     QList<HydrationJob *> hydrationJobs;
-    cfapi::ConnectionKey connectionKey;
+    CF_CONNECTION_KEY connectionKey = {};
 };
 
 VfsCfApi::VfsCfApi(QObject *parent)
@@ -155,9 +146,11 @@ void VfsCfApi::startImpl(const VfsSetupParams &params)
 
 void VfsCfApi::stop()
 {
-    const auto result = cfapi::disconnectSyncRoot(std::move(d->connectionKey));
-    if (!result) {
-        qCCritical(lcCfApi) << "Disconnect failed for" << QDir::toNativeSeparators(params().filesystemPath) << ":" << result.error();
+    if (d->connectionKey.Internal != 0) {
+        const auto result = cfapi::disconnectSyncRoot(std::move(d->connectionKey));
+        if (!result) {
+            qCCritical(lcCfApi) << "Disconnect failed for" << QDir::toNativeSeparators(params().filesystemPath) << ":" << result.error();
+        }
     }
 }
 
@@ -184,25 +177,25 @@ bool VfsCfApi::isHydrating() const
     return !d->hydrationJobs.isEmpty();
 }
 
-Result<void, QString> VfsCfApi::updateMetadata(const QString &filePath, time_t modtime, qint64 size, const QByteArray &fileId)
+OCC::Result<OCC::Vfs::ConvertToPlaceholderResult, QString> VfsCfApi::updateMetadata(const SyncFileItem &syncItem, const QString &filePath, const QString &replacesFile)
 {
     const auto localPath = QDir::toNativeSeparators(filePath);
-    if (cfapi::handleForPath(localPath)) {
-        auto result = cfapi::updatePlaceholderInfo(localPath, modtime, size, fileId);
-        if (result) {
-            return {};
-        } else {
-            return result.error();
-        }
+    const auto replacesPath = QDir::toNativeSeparators(replacesFile);
+
+    if (syncItem._type == ItemTypeVirtualFileDehydration) {
+        return cfapi::dehydratePlaceholder(localPath, syncItem._modtime, syncItem._size, syncItem._fileId);
     } else {
-        qCWarning(lcCfApi) << "Couldn't update metadata for non existing file" << localPath;
-        return {QStringLiteral("Couldn't update metadata")};
+        if (cfapi::findPlaceholderInfo(localPath)) {
+            return cfapi::updatePlaceholderInfo(localPath, syncItem, replacesPath);
+        } else {
+            return cfapi::convertToPlaceholder(localPath, syncItem, replacesPath);
+        }
     }
 }
 
-Result<Vfs::ConvertToPlaceholderResult, QString> VfsCfApi::updatePlaceholderMarkInSync(const QString &filePath, const QByteArray &fileId)
+Result<Vfs::ConvertToPlaceholderResult, QString> VfsCfApi::updatePlaceholderMarkInSync(const QString &filePath, const SyncFileItem &item)
 {
-    return cfapi::updatePlaceholderMarkInSync(filePath, fileId, {});
+    return cfapi::updatePlaceholderMarkInSync(filePath, item, {});
 }
 
 bool VfsCfApi::isPlaceHolderInSync(const QString &filePath) const
@@ -218,9 +211,25 @@ Result<void, QString> VfsCfApi::createPlaceholder(const SyncFileItem &item)
     return result;
 }
 
+Result<void, QString> VfsCfApi::createPlaceholders(const QList<SyncFileItemPtr> &items)
+{
+    const auto fileInfo = QFileInfo(_setupParams.filesystemPath + items[0]->_file);
+    const auto localPath = QDir::toNativeSeparators(fileInfo.absolutePath());
+
+    auto allPlaceholdersInfo = QList<cfapi::PlaceholdersInfo>{};
+    for (const auto &oneItem : items) {
+        auto fileInfo = QFileInfo(_setupParams.filesystemPath + oneItem->_file);
+        allPlaceholdersInfo.emplace_back(std::move(fileInfo), fileInfo.fileName(), QDir::toNativeSeparators(fileInfo.fileName()).toStdWString(), oneItem->_fileId, oneItem->_modtime, oneItem->_size);
+    }
+
+    const auto result = cfapi::createPlaceholdersInfo(localPath, {allPlaceholdersInfo});
+
+    return result;
+}
+
 Result<void, QString> VfsCfApi::dehydratePlaceholder(const SyncFileItem &item)
 {
-    const auto localPath = QDir::toNativeSeparators(_setupParams.filesystemPath + item._file);
+    const auto localPath = FileSystem::longWinPath(QDir::toNativeSeparators(_setupParams.filesystemPath + item._file));
     if (cfapi::handleForPath(localPath)) {
         auto result = cfapi::dehydratePlaceholder(localPath, item._modtime, item._size, item._fileId);
         if (result) {
@@ -236,17 +245,17 @@ Result<void, QString> VfsCfApi::dehydratePlaceholder(const SyncFileItem &item)
 
 Result<Vfs::ConvertToPlaceholderResult, QString> VfsCfApi::convertToPlaceholder(const QString &filename, const SyncFileItem &item, const QString &replacesFile, UpdateMetadataTypes updateType)
 {
-    const auto localPath = QDir::toNativeSeparators(filename);
-    const auto replacesPath = QDir::toNativeSeparators(replacesFile);
+    const auto localPath = FileSystem::longWinPath(QDir::toNativeSeparators(filename));
+    const auto replacesPath = FileSystem::longWinPath(QDir::toNativeSeparators(replacesFile));
 
     if (cfapi::findPlaceholderInfo(localPath)) {
-        if (updateType & Vfs::UpdateMetadataType::FileMetadata) {
-            return cfapi::updatePlaceholderInfo(localPath, item._modtime, item._size, item._fileId, replacesPath);
+        if (updateType.testFlag(Vfs::UpdateMetadataType::FileMetadata)) {
+            return cfapi::updatePlaceholderInfo(localPath, item, replacesPath);
         } else {
-            return cfapi::updatePlaceholderMarkInSync(localPath, item._fileId, replacesPath);
+            return cfapi::updatePlaceholderMarkInSync(localPath, item, replacesPath);
         }
     } else {
-        return cfapi::convertToPlaceholder(localPath, item._modtime, item._size, item._fileId, replacesPath);
+        return cfapi::convertToPlaceholder(localPath, item, replacesPath);
     }
 }
 
@@ -282,6 +291,8 @@ bool VfsCfApi::statTypeVirtualFile(csync_file_stat_t *stat, void *statData)
     if (isDirectory) {
         if (hasCloudTag) {
             ffd->dwFileAttributes &= ~FILE_ATTRIBUTE_REPARSE_POINT;
+            // stat->type = CSyncEnums::ItemTypeVirtualDirectory;
+            // return true;
         }
         return false;
     } else if (isSparseFile && isPinned) {
@@ -518,6 +529,48 @@ int VfsCfApi::finalizeHydrationJob(const QString &requestId)
     return HydrationJob::Status::Error;
 }
 
+int VfsCfApi::finalizeNewPlaceholders(const QList<PlaceholderCreateInfo> &newEntries,
+                                      const QString &pathString)
+{
+    const auto &journal = params().journal;
+
+    for (const auto &entryInfo : newEntries) {
+
+        auto folderRecord = SyncJournalFileRecord{};
+        folderRecord._fileId = entryInfo.parsedProperties.fileId;
+        folderRecord._fileSize = entryInfo.parsedProperties.size;
+        folderRecord._etag = entryInfo.parsedProperties.etag;
+        folderRecord._path = entryInfo.fullPath.toUtf8();
+        folderRecord._type = (entryInfo.parsedProperties.isDirectory ? ItemTypeVirtualDirectory : ItemTypeVirtualFile);
+        folderRecord._remotePerm = entryInfo.parsedProperties.remotePerm;
+        folderRecord._modtime = entryInfo.parsedProperties.modtime;
+
+        const auto updateRecordDbResult = journal->setFileRecord(folderRecord);
+        if (!updateRecordDbResult) {
+            qCWarning(lcCfApi) << "failed: failed to update db record for" << pathString;
+            return 0;
+        }
+    }
+
+    auto folderRecord = SyncJournalFileRecord{};
+    const auto fetchRecordDbResult = journal->getFileRecord(pathString, &folderRecord);
+    if (!fetchRecordDbResult || !folderRecord.isValid()) {
+        qCWarning(lcCfApi) << "failed: no valid db record for" << pathString;
+        return 0;
+    }
+
+    folderRecord._type = ItemTypeDirectory;
+    const auto updateRecordDbResult = journal->setFileRecord(folderRecord);
+    if (!updateRecordDbResult) {
+        qCWarning(lcCfApi) << "failed: failed to update db record for" << pathString;
+        return 0;
+    }
+
+    qCInfo(lcCfApi) << "update folder on-demand DB record succeeded" << pathString;
+
+    return 1;
+}
+
 VfsCfApi::HydratationAndPinStates VfsCfApi::computeRecursiveHydrationAndPinStates(const QString &folderPath, const Optional<PinState> &basePinState)
 {
     Q_ASSERT(!folderPath.endsWith('/'));
@@ -541,7 +594,7 @@ VfsCfApi::HydratationAndPinStates VfsCfApi::computeRecursiveHydrationAndPinState
         const auto dir = QDir(info.absoluteFilePath());
         Q_ASSERT(dir.exists());
         const auto children = dir.entryList();
-        return std::accumulate(std::cbegin(children), std::cend(children), dirState, [=](const HydratationAndPinStates &currentState, const QString &name) {
+        return std::accumulate(std::cbegin(children), std::cend(children), dirState, [=, this](const HydratationAndPinStates &currentState, const QString &name) {
             if (name == QStringLiteral("..") || name == QStringLiteral(".")) {
                 return currentState;
             }
