@@ -1,15 +1,6 @@
 /*
- * Copyright (C) by Claudio Cambra <claudio.cambra@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "gui/tray/activitydata.h"
@@ -51,8 +42,8 @@ public:
         const auto activityType = QStringLiteral("file");
         const auto activityId = 90000;
         const auto message = QString();
-        const auto objectName = QStringLiteral("test.").append(fileFormat);
-        const auto link = account->url().toString().append(QStringLiteral("/f/")).append(activityId);
+        const auto objectName = QStringLiteral("test.%1").arg(fileFormat);
+        const auto link = account->url().toString().append(QStringLiteral("/f/%1").arg(activityId));
         const auto datetime = QDateTime::currentDateTime().toString(Qt::ISODate);
         const auto icon = account->url().toString().append(QStringLiteral("/apps/files/img/add-color.svg"));
 
@@ -205,6 +196,11 @@ public:
 private slots:
     void initTestCase()
     {
+        OCC::Logger::instance()->setLogFlush(true);
+        OCC::Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
+
         account = OCC::Account::create();
         account->setCredentials(new FakeCredentials{fakeQnam.data()});
         account->setUrl(QUrl(("http://example.de")));
