@@ -1,3 +1,8 @@
+/*
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
 #include <QTest>
 
 #include "capabilities.h"
@@ -225,6 +230,61 @@ private slots:
 
         QVERIFY(!capabilities.userStatusSupportsEmoji());
     }
+
+    void testUserStatusSupportsBusy_supportsBusyAvailable_returnTrue()
+    {
+        QVariantMap userStatusMap;
+        userStatusMap["enabled"] = true;
+        userStatusMap["supports_busy"] = true;
+
+        QVariantMap capabilitiesMap;
+        capabilitiesMap["user_status"] = userStatusMap;
+
+        const OCC::Capabilities capabilities(capabilitiesMap);
+
+        QVERIFY(capabilities.userStatusSupportsBusy());
+    }
+
+    void testUserStatusSupportsBusy_supportsBusyNotAvailable_returnFalse()
+    {
+        QVariantMap userStatusMap;
+        userStatusMap["enabled"] = true;
+        userStatusMap["supports_busy"] = false;
+
+        QVariantMap capabilitiesMap;
+        capabilitiesMap["user_status"] = userStatusMap;
+
+        const OCC::Capabilities capabilities(capabilitiesMap);
+
+        QVERIFY(!capabilities.userStatusSupportsBusy());
+    }
+
+    void testUserStatusSupportsBusy_supportsBusyNotInCapabilities_returnFalse()
+    {
+        QVariantMap userStatusMap;
+        userStatusMap["enabled"] = true;
+
+        QVariantMap capabilitiesMap;
+        capabilitiesMap["user_status"] = userStatusMap;
+
+        const OCC::Capabilities capabilities(capabilitiesMap);
+
+        QVERIFY(!capabilities.userStatusSupportsBusy());
+    }
+
+    void testUserStatusSupportsBusy_userStatusNotEnabled_returnFalse()
+    {
+        QVariantMap userStatusMap;
+        userStatusMap["enabled"] = false;
+        userStatusMap["supports_busy"] = true;
+
+        QVariantMap capabilitiesMap;
+        capabilitiesMap["user_status"] = userStatusMap;
+
+        const OCC::Capabilities capabilities(capabilitiesMap);
+
+        QVERIFY(!capabilities.userStatusSupportsBusy());
+    }
     
     void testShareDefaultPermissions_defaultSharePermissionsNotInCapabilities_returnZero()
     {
