@@ -1,8 +1,11 @@
 /*
- *    This software is in the public domain, furnished "as is", without technical
- *    support, and with no warranty, express or implied, as to its usefulness for
- *    any purpose.
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2011 ownCloud GmbH
+ * SPDX-License-Identifier: CC0-1.0
  *
+ * This software is in the public domain, furnished "as is", without technical
+ * support, and with no warranty, express or implied, as to its usefulness for
+ * any purpose.
  */
 
 #include <QtTest>
@@ -284,7 +287,7 @@ private slots:
         // verify that office files for locking got detected by the watcher
         QScopedPointer<QSignalSpy> locksImposedSpy(new QSignalSpy(_watcher.data(), &FolderWatcher::filesLockImposed));
 
-        for (const auto &officeFile : listOfOfficeFiles) {
+        for (const auto &officeFile : std::as_const(listOfOfficeFiles)) {
             touch(officeFile);
             QVERIFY(waitForPathChanged(officeFile));
         }
@@ -325,7 +328,7 @@ private slots:
         for (const auto &officeLockFile : listOfOfficeLockFiles) {
             rm(officeLockFile);
         }
-        for (const auto &officeFile : listOfOfficeFiles) {
+        for (const auto &officeFile : std::as_const(listOfOfficeFiles)) {
             rm(officeFile);
         }
     }
@@ -340,7 +343,7 @@ private slots:
 
         const QStringList listOfOfficeLockFiles = {QString(_rootPath + "/.~lock.document.docx#"), QString(_rootPath + "/.~lock.document.odt#")};
 
-        for (const auto &officeFile : listOfOfficeFiles) {
+        for (const auto &officeFile : std::as_const(listOfOfficeFiles)) {
             touch(officeFile);
         }
         for (const auto &officeLockFile : listOfOfficeLockFiles) {
@@ -383,7 +386,7 @@ private slots:
         }
 
         // cleanup
-        for (const auto &officeFile : listOfOfficeFiles) {
+        for (const auto &officeFile : std::as_const(listOfOfficeFiles)) {
             rm(officeFile);
         }
         for (const auto &officeLockFile : listOfOfficeLockFiles) {
@@ -392,7 +395,7 @@ private slots:
     }
 };
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     QTEST_MAIN(TestFolderWatcher)
 #else
     QTEST_GUILESS_MAIN(TestFolderWatcher)
