@@ -1,8 +1,10 @@
 /*
- *    This software is in the public domain, furnished "as is", without technical
- *    support, and with no warranty, express or implied, as to its usefulness for
- *    any purpose.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: CC0-1.0
+ * 
+ * This software is in the public domain, furnished "as is", without technical
+ * support, and with no warranty, express or implied, as to its usefulness for
+ * any purpose.
  */
 
 #include <QtTest>
@@ -221,6 +223,7 @@ private slots:
         auto someDate = QDateTime(QDate(1984, 07, 30), QTime(1,3,2));
         fakeFolder.remoteModifier().setModTime("A/a1", someDate);
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
         QCOMPARE(QFileInfo(fakeFolder.localPath() + "A/a1").size(), 64);
         QCOMPARE(QFileInfo(fakeFolder.localPath() + "A/a1").lastModified(), someDate);
@@ -349,6 +352,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("B");
         fakeFolder.remoteModifier().insert("B/b1", 21);
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
         CFVERIFY_VIRTUAL(fakeFolder, "A/a2");
         CFVERIFY_VIRTUAL(fakeFolder, "B/b1");
@@ -451,6 +455,7 @@ private slots:
         fakeFolder.remoteModifier().insert("A/b4");
         QVERIFY(fakeFolder.syncOnce());
 
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
         CFVERIFY_VIRTUAL(fakeFolder, "A/a2");
         CFVERIFY_VIRTUAL(fakeFolder, "A/a3");
@@ -543,6 +548,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("A");
         fakeFolder.remoteModifier().insert("A/a1");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
         cleanup();
 
@@ -572,6 +578,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("A");
         fakeFolder.remoteModifier().insert("A/a1");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
 
         ::setPinState(fakeFolder.localPath(), PinState::AlwaysLocal, cfapi::NoRecurse);
@@ -606,6 +613,7 @@ private slots:
         fakeFolder.remoteModifier().insert("B/Sub/b2");
         QVERIFY(fakeFolder.syncOnce());
 
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
         CFVERIFY_VIRTUAL(fakeFolder, "A/a2");
         CFVERIFY_VIRTUAL(fakeFolder, "A/Sub/a3");
@@ -894,6 +902,7 @@ private slots:
         QVERIFY(fakeFolder.syncOnce());
 
         CFVERIFY_VIRTUAL(fakeFolder, "f1");
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         CFVERIFY_VIRTUAL(fakeFolder, "A/a1");
         // CFVERIFY_VIRTUAL(fakeFolder, "A/a3");
         CFVERIFY_VIRTUAL(fakeFolder, "A/B/b1");
@@ -942,6 +951,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("online");
         fakeFolder.remoteModifier().mkdir("unspec");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         ::setPinState(fakeFolder.localPath() + "local", PinState::AlwaysLocal, cfapi::Recurse);
@@ -1025,6 +1035,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("online/sub");
         fakeFolder.remoteModifier().mkdir("unspec");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         ::setPinState(fakeFolder.localPath() + "local", PinState::AlwaysLocal, cfapi::Recurse);
@@ -1085,6 +1096,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("online");
         fakeFolder.remoteModifier().mkdir("unspec");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         ::setPinState(fakeFolder.localPath() + "local", PinState::AlwaysLocal, cfapi::NoRecurse);
@@ -1190,6 +1202,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("local");
         fakeFolder.remoteModifier().mkdir("online");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         ::setPinState(fakeFolder.localPath() + "local", PinState::AlwaysLocal, cfapi::NoRecurse);
@@ -1243,6 +1256,7 @@ private slots:
         fakeFolder.remoteModifier().mkdir("online");
         fakeFolder.remoteModifier().mkdir("online/sub");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         ::setPinState(fakeFolder.localPath() + "online", PinState::OnlineOnly, cfapi::Recurse);
@@ -1321,6 +1335,7 @@ private slots:
         fakeFolder.syncEngine().setLocalDiscoveryOptions(OCC::LocalDiscoveryStyle::DatabaseAndFilesystem);
         QVERIFY(fakeFolder.syncOnce());
 
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
@@ -1340,6 +1355,7 @@ private slots:
         QCOMPARE(completeSpy.findItem(QStringLiteral("A/a1"))->_locked, OCC::SyncFileItem::LockStatus::UnlockedItem);
         OCC::SyncJournalFileRecord fileRecordBefore;
         QVERIFY(fakeFolder.syncJournal().getFileRecord(QStringLiteral("A/a1"), &fileRecordBefore));
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QVERIFY(fileRecordBefore.isValid());
         QVERIFY(!fileRecordBefore._lockstate._locked);
 
@@ -1437,6 +1453,7 @@ private slots:
         fakeFolder.remoteModifier().remove("a/TESTFILE");
         fakeFolder.remoteModifier().mkdir("a/TESTFILE");
         QVERIFY(fakeFolder.syncOnce());
+        // QEXPECT_FAIL("", "folders on-demand breaks existing tests", Abort);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
 
@@ -1515,6 +1532,56 @@ private slots:
         QVERIFY(fakeFolder.currentRemoteState().find("S/A/a2m"));
         QVERIFY(fakeFolder.currentRemoteState().find("S/B/b2m"));
     }
+
+    void createFolderAndFiles()
+    {
+        FakeFolder fakeFolder {FileInfo{}};
+        auto vfs = setupVfs(fakeFolder);
+
+        fakeFolder.remoteModifier().mkdir("first folder");
+
+        QVERIFY(fakeFolder.syncOnce());
+
+        fakeFolder.remoteModifier().insert("first folder/file1");
+        fakeFolder.remoteModifier().insert("first folder/file2");
+        fakeFolder.remoteModifier().insert("first folder/file3");
+        fakeFolder.remoteModifier().mkdir("first folder/second folder");
+        fakeFolder.remoteModifier().insert("first folder/second folder/second file1");
+        fakeFolder.remoteModifier().insert("first folder/second folder/second file2");
+        fakeFolder.remoteModifier().insert("first folder/second folder/second file3");
+
+        QVERIFY(fakeFolder.syncOnce());
+        QCOMPARE(fakeFolder.currentRemoteState(), fakeFolder.currentRemoteState());
+    }
+
+    void testSyncFolderNewDeleteConflictExpectDeletion()
+    {
+        // QSKIP("folders on-demand breaks existing tests");
+
+        FakeFolder fakeFolder{FileInfo{}};
+        setupVfs(fakeFolder);
+
+        fakeFolder.remoteModifier().mkdir("directory");
+        fakeFolder.remoteModifier().mkdir("directory/subdir");
+        fakeFolder.remoteModifier().insert("directory/file1");
+        fakeFolder.remoteModifier().insert("directory/file2");
+        fakeFolder.remoteModifier().insert("directory/file3");
+        fakeFolder.remoteModifier().insert("directory/subdir/fileTxt1.txt");
+        fakeFolder.remoteModifier().insert("directory/subdir/fileTxt2.txt");
+        fakeFolder.remoteModifier().insert("directory/subdir/fileTxt3.txt");
+
+        // perform an initial sync to ensure local and remote have the same state
+        QVERIFY(fakeFolder.syncOnce());
+
+        fakeFolder.remoteModifier().remove("directory");
+        fakeFolder.localModifier().mkdir("directory/subFolder");
+        fakeFolder.localModifier().insert("directory/file4");
+        fakeFolder.localModifier().insert("directory/subdir/fileTxt4.txt");
+
+        QVERIFY(fakeFolder.syncOnce());
+        const auto directoryItem = fakeFolder.remoteModifier().find("directory");
+        QCOMPARE(directoryItem, nullptr);
+    }
 };
 
 QTEST_GUILESS_MAIN(TestSyncCfApi)
